@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1997  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -23,7 +23,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 
 #ifndef _FUNCTIONINFO_H_
@@ -172,6 +172,7 @@ public:
 	void SetCalls(int tid, long calls) { NumCalls[tid] = calls; }
 	long GetSubrs(int tid) { return NumSubrs[tid]; }
 	void SetSubrs(int tid, long subrs) { NumSubrs[tid] = subrs; }
+	void FunctionInfo::ResetExclTimeIfNegative(int tid);
 
 #ifndef TAU_MULTIPLE_COUNTERS
 	double GetExclTime(int tid) { return ExclTime[tid]; }
@@ -195,6 +196,10 @@ public:
 	//Returns the array of inclusive counter values.
 	//double * GetInclTime(int tid) { return InclTime[tid]; }
 	double * GetInclTime(int tid);
+	void AddInclTimeForCounter(double value, int tid, int counter) { InclTime[tid][counter] += value; }
+	void AddExclTimeForCounter(double value, int tid, int counter) { ExclTime[tid][counter] += value; }
+	double GetInclTimeForCounter(int tid, int counter) { return InclTime[tid][counter]; }
+	double GetExclTimeForCounter(int tid, int counter) { return InclTime[tid][counter]; }
 	void SetInclTime(int tid, double *incltime) { 
 	  for(int i=0;i<MAX_TAU_COUNTERS;i++)
 	    InclTime[tid][i] = incltime[i];
@@ -205,8 +210,8 @@ public:
         }
 #endif//TAU_MULTIPLE_COUNTERS
 
-	TauGroup_t GetProfileGroup() const {return MyProfileGroup_; }
-	void SetProfileGroup(TauGroup_t gr) {MyProfileGroup_ = gr; }
+	TauGroup_t GetProfileGroup(int tid = RtsLayer::myThread()) const {return MyProfileGroup_[tid]; }
+	void SetProfileGroup(TauGroup_t gr, int tid) {MyProfileGroup_[tid] = gr; }
 #ifdef PROFILE_STATS 
 	double GetSumExclSqr(int tid) { return SumExclSqr[tid]; }
 	void SetSumExclSqr(int tid, double s) { SumExclSqr[tid] = s; }
@@ -215,7 +220,7 @@ public:
 #endif // PROFILE_STATS 
 
 private:
-	TauGroup_t MyProfileGroup_;
+	TauGroup_t MyProfileGroup_[TAU_MAX_THREADS];
 };
 
 // Global variables
@@ -308,6 +313,6 @@ void tauCreateFI(FunctionInfo **ptr, const string& name, const string& type,
 #endif /* _FUNCTIONINFO_H_ */
 /***************************************************************************
  * $RCSfile: FunctionInfo.h,v $   $Author: sameer $
- * $Revision: 1.31 $   $Date: 2005/05/17 19:32:10 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.31 2005/05/17 19:32:10 sameer Exp $ 
+ * $Revision: 1.36 $   $Date: 2005/11/11 18:22:46 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.36 2005/11/11 18:22:46 sameer Exp $ 
  ***************************************************************************/
