@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1997  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -23,7 +23,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 #ifndef PROFILER_H
 #define PROFILER_H
@@ -57,6 +57,10 @@
 #define TAU_MAX_THREADS 1
 #endif /* PTHREADS || TULIPTHREADS || JAVA || TAU_WINDOWS || OPENMP || SPROC */
 
+/* We should throttle if number n > a && percall < b .a and b are given below */
+#define TAU_THROTTLE_NUMCALLS_DEFAULT 100000
+#define TAU_THROTTLE_PERCALL_DEFAULT  10
+
 #include <Profile/TauAPI.h>
 
 #if (defined(PROFILING_ON) || defined(TRACING_ON))
@@ -113,7 +117,7 @@ public:
 	Profiler(const Profiler& X);
 	Profiler& operator= (const Profiler& X);
 	// Clean up data from this invocation.
-	void Stop(int tid = RtsLayer::myThread());
+	void Stop(int tid = RtsLayer::myThread(), bool useLastTimeStamp = false);
 	~Profiler();
 #ifdef TAU_CALLPATH
         void CallPathStart(int tid);
@@ -205,6 +209,9 @@ public:
 #ifdef TAU_MPITRACE
 	void EnableAllEventsOnCallStack(int tid, Profiler *current);
 #endif /* TAU_MPITRACE */
+	bool& TheTauThrottle(void);
+	double& TheTauThrottlePerCall(void);
+	double& TheTauThrottleNumCalls(void);
 
 private:
 	TauGroup_t MyProfileGroup_;
@@ -234,7 +241,7 @@ private:
 
 #endif /* PROFILER_H */
 /***************************************************************************
- * $RCSfile: Profiler.h,v $   $Author: sameer $
- * $Revision: 1.59 $   $Date: 2005/05/27 22:09:47 $
- * POOMA_VERSION_ID: $Id: Profiler.h,v 1.59 2005/05/27 22:09:47 sameer Exp $ 
+ * $RCSfile: Profiler.h,v $   $Author: amorris $
+ * $Revision: 1.62 $   $Date: 2005/11/11 03:46:47 $
+ * POOMA_VERSION_ID: $Id: Profiler.h,v 1.62 2005/11/11 03:46:47 amorris Exp $ 
  ***************************************************************************/
