@@ -1,7 +1,7 @@
 
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1997  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -24,7 +24,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 
 #ifndef _TAU_CAPI_H_
@@ -65,7 +65,7 @@ extern "C" {
 #define TAU_INIT(argc, argv)			Tau_init_ref(argc, argv);
 #define TAU_PROFILE_SET_NODE(node) 		Tau_set_node(node);
 #define TAU_PROFILE_SET_CONTEXT(context)	Tau_set_context(context);
-#define TAU_PROFILE_CALLSTACK()			Tau_callstack();
+#define TAU_PROFILE_CALLSTACK()			Tau_profile_callstack();
 #define TAU_DB_DUMP()                           Tau_dump();
 #define TAU_DB_DUMP_PREFIX(prefix)              Tau_dump_prefix(prefix);
 #define TAU_DB_DUMP_INCR()                      Tau_dump_incr();
@@ -150,7 +150,7 @@ extern "C" {
 #define TAU_SET_INTERRUPT_INTERVAL(value)	Tau_set_interrupt_interval(value)
 #define TAU_PHASE_CREATE_STATIC(var, name, type, group) static void *var##finfo = NULL; Tau_profile_c_timer(&var##finfo, name, type, group, Tau_phase_enable_once(#group, &var##finfo))
 #define TAU_PHASE_CREATE_DYNAMIC(var, name, type, group) void *var##finfo = NULL; Tau_profile_c_timer(&var##finfo, name, type, group, Tau_phase_enable_once(#group, &var##finfo))
-#define TAU_PROFILE_TIMER_DYNAMIC(var, name, type, group) void *var##finfo = NULL; Tau_profile_c_timer(&var##finfo, name, type, group, #group)
+#define TAU_PROFILE_TIMER_DYNAMIC(var, name, type, group) void *var = NULL; Tau_profile_c_timer(&var, name, type, group, #group)
 #define TAU_PHASE_START(var) Tau_start_timer(var##finfo, 1)
 #define TAU_PHASE_STOP(var) Tau_stop_timer(var##finfo)
 #define TAU_GLOBAL_PHASE(timer, name, type, group) void * TauGlobalPhase##timer(void) \
@@ -354,8 +354,8 @@ extern char * Tau_phase_enable_once(const char *group, void **ptr);
 #endif /* _TAU_CAPI_H_ */
 
 /***************************************************************************
- * $RCSfile: TauCAPI.h,v $   $Author: sameer $
- * $Revision: 1.40 $   $Date: 2005/08/11 02:12:10 $
- * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.40 2005/08/11 02:12:10 sameer Exp $
+ * $RCSfile: TauCAPI.h,v $   $Author: amorris $
+ * $Revision: 1.43 $   $Date: 2005/11/11 03:46:47 $
+ * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.43 2005/11/11 03:46:47 amorris Exp $
  ***************************************************************************/
 
