@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1997  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -11,7 +11,7 @@
 **	Description 	: TAU Profiling Package				  **
 **	Author		: Sameer Shende					  **
 **	Contact		: sameer@cs.uoregon.edu 		 	  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 #ifndef _TAU_H_
 #define _TAU_H_
@@ -40,6 +40,13 @@
 #define TAU_DB_DUMP()
 #define TAU_DB_PURGE()
 
+
+#define TAU_REGISTER_CONTEXT_EVENT(event, name)
+#define TAU_CONTEXT_EVENT(event, data)
+#define TAU_DISABLE_CONTEXT_EVENT(event)
+#define TAU_ENABLE_CONTEXT_EVENT(event)
+
+
 #define TAU_REGISTER_EVENT(event, name)
 #define TAU_EVENT(event, data)
 #define TAU_EVENT_DISABLE_MIN(event)
@@ -100,6 +107,7 @@
 #define TAU_MAPPING_PROFILE_GET_TYPE(timer)
 
 
+#define TAU_PHASE(name, type, group) 
 #define TAU_PHASE_CREATE_STATIC(var, name, type, group) 
 #define TAU_PHASE_CREATE_DYNAMIC(var, name, type, group) 
 #define TAU_PHASE_START(var) 
