@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1997  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -23,7 +23,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 
 //////////////////////////////////////////////////////////////////////
@@ -165,7 +165,9 @@ void FunctionInfo::FunctionInfoInit(TauGroup_t ProfileGroup,
 #endif //PROFILE_CALLS
 	// Make this a ptr to a list so that ~FunctionInfo doesn't destroy it.
 	
-        MyProfileGroup_ = ProfileGroup ;
+	for (int i=0; i<TAU_MAX_THREADS; i++) {
+	  MyProfileGroup_[i] = ProfileGroup;
+	}
 	// While accessing the global function database, lock it to ensure
 	// an atomic operation in the push_back and size() operations. 
 	// Important in the presence of concurrent threads.
@@ -315,12 +317,33 @@ long FunctionInfo::GetFunctionId(void)
 	return FunctionId;
 }
 	    
+
 //////////////////////////////////////////////////////////////////////
+void FunctionInfo::ResetExclTimeIfNegative(int tid) 
+{ /* if exclusive time is negative (at Stop) we set it to zero during
+     compensation. This function is used to reset it to zero for single
+     and multiple counters */
+  	int i;
+#ifndef TAU_MULTIPLE_COUNTERS
+	if (ExclTime[tid] < 0)
+        {
+          ExclTime[tid] = 0.0;
+        }
+#else /* TAU_MULTIPLE_COUNTERS */
+	for (i=0; i < MAX_TAU_COUNTERS; i++)
+	{
+	  if (ExclTime[tid][i] < 0)
+          {
+            ExclTime[tid][i] = 0.0; /* set each negative counter to zero */
+          }
+        }
+#endif /* TAU_MULTIPLE_COUNTERS */
+        return; 
+}
 
 
 
-
-
+//////////////////////////////////////////////////////////////////////
 void tauCreateFI(FunctionInfo **ptr, const char *name, const char *type, 
 		 TauGroup_t ProfileGroup , const char *ProfileGroupName) {
   if (*ptr == 0) {
@@ -408,6 +431,6 @@ void tauCreateFI(FunctionInfo **ptr, const string& name, const string& type,
 }
 /***************************************************************************
  * $RCSfile: FunctionInfo.cpp,v $   $Author: sameer $
- * $Revision: 1.38 $   $Date: 2005/05/17 19:33:23 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.cpp,v 1.38 2005/05/17 19:33:23 sameer Exp $ 
+ * $Revision: 1.41 $   $Date: 2005/11/11 18:27:00 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.cpp,v 1.41 2005/11/11 18:27:00 sameer Exp $ 
  ***************************************************************************/
