@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1999  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -23,7 +23,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 
 //////////////////////////////////////////////////////////////////////
@@ -59,6 +59,9 @@ using namespace std;
 #if (!defined(TAU_WINDOWS))
 #include <unistd.h>
 
+#include <sys/types.h>
+#include <sys/stat.h>
+
 #if (defined(POOMA_TFLOP) || !defined(TULIP_TIMERS))
 #include <sys/time.h>
 #else
@@ -93,6 +96,16 @@ Profiler * Profiler::CurrentProfiler[] = {0}; // null to start with
 // Default value of Node.
 //int RtsLayer::Node = -1;
 
+//////////////////////////////////////////////////////////////////////
+// For OpenMP
+//////////////////////////////////////////////////////////////////////
+#ifdef TAU_OPENMP 
+#ifndef TAU_MULTIPLE_COUNTERS
+double TheLastTimeStamp[TAU_MAX_THREADS]; 
+#else /* FOR MULTIPLE COUNTERS */
+double TheLastTimeStamp[TAU_MAX_THREADS][MAX_TAU_COUNTERS]; 
+#endif /* MULTIPLE_COUNTERS */
+#endif /* TAU_OPENMP */
 //////////////////////////////////////////////////////////////////////
 // Explicit Instantiations for templated entities needed for ASCI Red
 //////////////////////////////////////////////////////////////////////
@@ -239,6 +252,14 @@ void Profiler::Start(int tid)
       }
 #endif /* TAU_DEPTH_LIMIT */
 
+#ifdef TAU_PROFILEPHASE
+      if (ParentProfiler == (Profiler *) NULL) {
+	if (ThisFunction->AllGroups.find("TAU_PHASE", 0) == string::npos) {
+	  ThisFunction->AllGroups.append(" | TAU_PHASE"); 
+	}
+      }
+#endif /* TAU_PROFILEPHASE */
+
       x_uint64 TimeStamp = 0L;
 
       DEBUGPROFMSG("Profiler::Start: MyProfileGroup_ = " << MyProfileGroup_ 
@@ -303,9 +324,29 @@ void Profiler::Start(int tid)
 #endif /* TAU_MPITRACE */
 #endif /* TRACING_ON */
 
+/* What do we maintain if PROFILING is turned off and tracing is turned on and
+   throttling is not disabled? We need to maintain enough info to generate 
+   inclusive time and keep information about AddInclFlag */
+#ifndef PROFILING_ON
+#ifdef  TRACING_ON
+#ifndef TAU_DISABLE_THROTTLE
+        if (TheTauThrottle() && (ThisFunction->GetAlreadyOnStack(tid)== false))
+        {
+          /* Set the callstack flag */
+          AddInclFlag = true; 
+	  ThisFunction->SetAlreadyOnStack(true, tid); // it is on callstack now
+
+	  // Next, increment the number of calls
+	  ThisFunction->IncrNumCalls(tid);
+        }
+#endif /* TAU_DISABLE_THROTTLE is off */
+#endif /* TRACING is on */
+#endif /* PROFILING is off */
+
 #ifdef PROFILING_ON
 	// First, increment the number of calls
 	ThisFunction->IncrNumCalls(tid);
+
         // now increment parent's NumSubrs()
 	if (ParentProfiler != 0)
           ParentProfiler->ThisFunction->IncrNumSubrs(tid);	
@@ -363,7 +404,9 @@ Profiler::Profiler( FunctionInfo * function, TauGroup_t ProfileGroup,
 {
 
       StartStopUsed_ = StartStop; // will need it later in ~Profiler
-      MyProfileGroup_ = ProfileGroup ;
+      MyProfileGroup_ = function->GetProfileGroup(tid) ;
+      //MyProfileGroup_ = ProfileGroup;
+      /* Get the latest profile group from the function. For throttling. */
       ThisFunction = function ; 
 #ifdef TAU_MPITRACE
       RecordEvent = false; /* by default, we don't record this event */
@@ -444,7 +487,7 @@ Profiler& Profiler::operator= (const Profiler& X)
 
 //////////////////////////////////////////////////////////////////////
 
-void Profiler::Stop(int tid)
+void Profiler::Stop(int tid, bool useLastTimeStamp)
 {
       x_uint64 TimeStamp = 0L; 
       if (CurrentProfiler[tid] == NULL) return;
@@ -480,9 +523,23 @@ void Profiler::Stop(int tid)
 #endif /* TAU_COMPENSATE */
 
 #ifndef TAU_MULTIPLE_COUNTERS
-	double CurrentTime = RtsLayer::getUSecD(tid);
+        double CurrentTime; 
+	if (useLastTimeStamp) /* for openmp parallel regions */
+        { /* .TAU Application needs to be stopped */
+#ifdef TAU_OPENMP 
+          CurrentTime = TheLastTimeStamp[tid]; 
+#endif /* TAU_OPENMP */
+        }
+	else
+	{ /* use the usual mechanism */
+	  CurrentTime = RtsLayer::getUSecD(tid);
+        }
 	double TotalTime = CurrentTime - StartTime;
 	TimeStamp += (x_uint64) CurrentTime; 
+        
+#ifdef TAU_OPENMP
+        TheLastTimeStamp[tid] = CurrentTime;
+#endif /* TAU_OPENMP */
 
 
 #if (defined(TAU_COMPENSATE ) && defined(PROFILING_ON))
@@ -501,7 +558,23 @@ void Profiler::Stop(int tid)
 	  CurrentTime[i] = 0;
 	}
 	//Get the current counter values.
-	RtsLayer::getUSecD(tid, CurrentTime);
+	if (useLastTimeStamp) /* for openmp parallel regions */
+        { /* .TAU Application needs to be stopped */
+#ifdef TAU_OPENMP 
+	  for (i=0; i < MAX_TAU_COUNTERS; i++)
+            CurrentTime[i] = TheLastTimeStamp[tid][i]; 
+#endif /* TAU_OPENMP */
+        }
+	else
+	{ /* use the usual mechanism */
+	  RtsLayer::getUSecD(tid, CurrentTime);
+        }
+#ifdef TAU_OPENMP
+        for (i=0; i < MAX_TAU_COUNTERS; i++)
+        {
+          TheLastTimeStamp[tid][i] = CurrentTime[i]; 
+        }
+#endif /* TAU_OPENMP */
 
 #ifdef PROFILING_ON
 #ifdef TAU_COMPENSATE
@@ -546,6 +619,28 @@ void Profiler::Stop(int tid)
 #endif /* TAU_EPILOG */
 #endif //TRACING_ON
 
+/* What should we do while exiting when profiling is off, tracing is on and 
+   throttling is on? */
+#ifndef PROFILING_ON
+#ifdef  TRACING_ON
+#ifndef TAU_DISABLE_THROTTLE
+        if (TheTauThrottle() && AddInclFlag)
+        {
+	  ThisFunction->SetAlreadyOnStack(false, tid); // while exiting
+
+	  // Next, compute inclusive time for counter 0
+#ifdef TAU_MULTIPLE_COUNTERS
+          double TimeTaken = CurrentTime[0] - StartTime[0];
+	  ThisFunction->AddInclTimeForCounter(TimeTaken, tid, 0);
+#else /* single counter */
+          double TimeTaken = CurrentTime - StartTime;
+	  ThisFunction->AddInclTime(TimeTaken, tid);
+#endif /* TAU_MULTIPLE_COUNTERS */ /* we only maintain inclusive time for counter 0 */
+        }
+#endif /* TAU_DISABLE_THROTTLE is off */
+#endif /* TRACING is on */
+#endif /* PROFILING is off */
+
 #ifdef PROFILING_ON  // Calculations relevent to profiling only 
 
 #ifdef TAU_CALLPATH
@@ -577,40 +672,11 @@ void Profiler::Stop(int tid)
 	// In either case we need to add time to the exclusive time.
 
 #ifdef TAU_COMPENSATE
-#ifndef TAU_MULTIPLE_COUNTERS
-	if (ThisFunction->GetExclTime(tid) < 0) 
-	{
- 	  ThisFunction->SetExclTime(tid, 0.0);
-	}
-#else /* TAU_MULTIPLE_COUNTERS */
- 	/* Lets get the vector of exclusive times for each counter */
-	double * exclcounters= ThisFunction->GetExclTime(tid);
-        for(i = 0; i < MAX_TAU_COUNTERS; i++)	
-	{
-	  if (exclcounters[i] < 0)
-	    exclcounters[i] = 0.0; 
-	}
- 	ThisFunction->SetExclTime(tid, exclcounters);
-#endif /* TAU_MULTIPLE_COUNTERS */
+        ThisFunction->ResetExclTimeIfNegative(tid); 
 #ifdef TAU_CALLPATH
-
-
-#ifndef TAU_MULTIPLE_COUNTERS
-	if ((ParentProfiler != NULL) && (CallPathFunction->GetExclTime(tid) < 0)) 
-	{
- 	  CallPathFunction->SetExclTime(tid, 0.0);
-	}
-#else /* TAU_MULTIPLE_COUNTERS */
 	if (ParentProfiler != NULL) {
-	  double *exclcounters = CallPathFunction->GetExclTime(tid);
-	  for(i = 0; i < MAX_TAU_COUNTERS; i++)	
-	    {
-	      if (exclcounters[i] < 0)
-		exclcounters[i] = 0.0; 
-	    }
-	  CallPathFunction->SetExclTime(tid, exclcounters);
+          CallPathFunction->ResetExclTimeIfNegative(tid); 
 	}
-#endif /* TAU_MULTIPLE_COUNTERS */
 #endif /* TAU_CALLPATH */
 #endif /* TAU_COMPENSATE */
 
@@ -667,8 +733,34 @@ void Profiler::Stop(int tid)
 #endif /* TAU_COMPENSATE */
 
 	}
-	
+
 #endif //PROFILING_ON
+
+/* if the frequency of events is high, disable them */
+#ifndef TAU_DISABLE_THROTTLE /* unless we are overriding the throttle */
+	double inclusiveTime; 
+#ifdef TAU_MULTIPLE_COUNTERS
+	inclusiveTime = ThisFunction->GetInclTimeForCounter(tid, 0); 
+	/* here we get the array of double values representing the double 
+           metrics. We choose the first counter */
+#else  /* TAU_MULTIPLE_COUNTERS */
+        inclusiveTime = ThisFunction->GetInclTime(tid); 
+	/* when multiple counters are not used, it is a single metric or double */
+#endif /* MULTIPLE_COUNTERS */
+        DEBUGPROFMSG("Calls = "<<ThisFunction->GetCalls(tid)
+          <<" inclusiveTime = "<<inclusiveTime
+          <<" TheTauThrottle = "<<TheTauThrottle() 
+          <<" ThrCalls = "<<TheTauThrottleNumCalls()
+	  <<" PerCall = " <<TheTauThrottlePerCall()<<endl;);
+        if (TheTauThrottle() && (ThisFunction->GetCalls(tid) > TheTauThrottleNumCalls()) && (inclusiveTime/ThisFunction->GetCalls(tid) < TheTauThrottlePerCall()) && AddInclFlag)
+	{ /* Putting AddInclFlag means we can't throttle recursive calls */
+	  ThisFunction->SetProfileGroup(TAU_DISABLE, tid);
+	  ThisFunction->SetPrimaryGroupName("TAU_DISABLE");
+	  cout <<"TAU<"<<RtsLayer::myNode()<<">: Throttle: Disabling "<<ThisFunction->GetName()<<endl;
+	}
+#endif /* TAU_DISABLE_THROTTLE */
+      
+	
 	// First check if timers are overlapping.
 	if (CurrentProfiler[tid] != this) {
 	  DEBUGPROFMSG("nct "<< RtsLayer::myNode() << ","
@@ -701,9 +793,6 @@ void Profiler::Stop(int tid)
 	    << this<<endl;);
 
         if (ParentProfiler == (Profiler *) NULL) {
-#ifdef TAU_PROFILEPHASE
-	  ThisFunction->AllGroups.append(" | TAU_PHASE"); 
-#endif /* TAU_PROFILEPHASE */
 
 	  // For Dyninst. tcf gets called after main and all the data structures may not be accessible
 	  // after main exits. Still needed on Linux - we use TauProgramTermination()
@@ -720,6 +809,22 @@ void Profiler::Stop(int tid)
               << ThisFunction->GetName() <<endl;);
   
               StoreData(tid);
+#ifdef TAU_OPENMP /* Check if we need to shut off .TAU applications on other tids */
+              if (tid == 0) 
+              {
+                 int i; 
+                 for (i = 1; i < TAU_MAX_THREADS; i++)
+		 {  /* for all other threads */
+	           Profiler *cp = CurrentProfiler[i];
+                   if (cp && strncmp(cp->ThisFunction->GetName(),".TAU", 4) == 0)
+		   {
+		     bool uselasttimestamp = true;
+                     cp->Stop(i,uselasttimestamp); /* force it to write the data*/
+                   }
+                 }
+              }
+	     
+#endif /* TAU_OPENMP */
 	    }
         // dump data here. Dump it only at the exit of top level profiler.
 	  }
@@ -1004,7 +1109,12 @@ void Profiler::getFunctionValues(const char **inFuncs,
 	  
 	  while (current != 0){
 	    /* Traverse the stack */ 
-	    if ((*it) == current->ThisFunction){ /* Match! */
+#ifdef TAU_CALLPATH
+	    if ((*it) == current->ThisFunction || (*it) == current->CallPathFunction) {
+#else
+	    if ((*it) == current->ThisFunction) { 
+#endif
+	      /* Match! */
 	      DEBUGPROFMSG("MATCH! Name :"<<current->ThisFunction->GetName()
 			   <<endl;);
 	      total = currenttime - current->StartTime;
@@ -1170,7 +1280,14 @@ int Profiler::dumpFunctionValues(const char **inFuncs,
 		prevtime = 0; /* for reducing from the parent profiler */
 		while (current != 0){
 		  /* Traverse the stack */ 
-		  if ((*it) == current->ThisFunction){ /* Match! */
+
+#ifdef TAU_CALLPATH
+		  if ((*it) == current->ThisFunction || (*it) == current->CallPathFunction) {
+#else
+		  if ((*it) == current->ThisFunction) { 
+#endif
+		    /* Match! */
+		    
 		    DEBUGPROFMSG("MATCH! Name :"<<current->ThisFunction->GetName()
 				 <<endl;);
 		    total = currenttime - current->StartTime; 
@@ -1585,10 +1702,15 @@ int Profiler::DumpData(bool increment, int tid, char *prefix)
 		while (current != 0) 
 		{
 		  /* Traverse the stack */ 
-		  if ((*it) == current->ThisFunction) 
-	 	  { /* Match! */
-		    DEBUGPROFMSG("MATCH! Name :"<<current->ThisFunction->GetName()
-	  	      <<endl;);
+		  
+#ifdef TAU_CALLPATH
+		  if ((*it) == current->ThisFunction || (*it) == current->CallPathFunction) {
+#else
+		  if ((*it) == current->ThisFunction) { 
+#endif
+		    /* Match! */
+		    DEBUGPROFMSG("MATCH! Name :"<<current->ThisFunction->GetName() << endl;);
+		    
 		    total = currenttime - current->StartTime; 
 		    excltime += total - prevtime; 
 		    /* prevtime is the inclusive time of the subroutine that should
@@ -1776,7 +1898,11 @@ bool Profiler::createDirectories(){
       sprintf(mkdircommand,"mkdir -p %s",newdirname);
     
       //system(rmdircommand);
-      system(mkdircommand);
+      //system(mkdircommand);
+      /* On IBM BGL, system command doesn't execute. So, we need to create
+      these directories using our mkdir syscall instead. */
+      mkdir(newdirname, S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
+     
     }
   }
     flag = false;
@@ -1882,8 +2008,16 @@ void Profiler::getFunctionValues(const char **inFuncs,
 	  }
 	  
 	  while (current != 0){
-	    /* Traverse the stack */ 
-	    if ((*it) == current->ThisFunction){ /* Match! */
+	    /* Traverse the stack */
+
+
+#ifdef TAU_CALLPATH
+	      if ((*it) == current->ThisFunction || (*it) == current->CallPathFunction) {
+#else
+	      if ((*it) == current->ThisFunction) { 
+#endif
+		/* Match! */
+ 
 	      DEBUGPROFMSG("MATCH! Name :"<<current->ThisFunction->GetName()
 			   <<endl;);
 	      
@@ -2089,7 +2223,13 @@ int Profiler::dumpFunctionValues(const char **inFuncs,
 	      
 	      while (current != 0){
 		/* Traverse the stack */ 
-		if ((*it) == current->ThisFunction){ /* Match! */
+
+#ifdef TAU_CALLPATH
+		if ((*it) == current->ThisFunction || (*it) == current->CallPathFunction) {
+#else
+		if ((*it) == current->ThisFunction) { 
+#endif
+		  /* Match! */
 		  DEBUGPROFMSG("MATCH! Name :"<<current->ThisFunction->GetName()
 			       <<endl;);
 		  
@@ -2381,8 +2521,8 @@ int Profiler::StoreData(int tid){
   return 1;
 }
 int Profiler::DumpData(bool increment, int tid, char *prefix){
-  
-  TAU_PROFILE("TAU_DUMP_DB()", " ", TAU_IO);
+
+  TAU_PROFILE("TAU_DB_DUMP()", " ", TAU_IO);
 
 #ifdef PROFILING_ON
   vector<FunctionInfo*>::iterator it;
@@ -2437,10 +2577,10 @@ int Profiler::DumpData(bool increment, int tid, char *prefix){
 
       DEBUGPROFMSG("Creating " << filename << endl;);
       if ((fp = fopen (filename, "w+")) == NULL) {
-      errormsg = new char[1024];
-      sprintf(errormsg,"Error: Could not create %s",filename);
-      perror(errormsg);
-      return 0;
+	errormsg = new char[1024];
+	sprintf(errormsg,"Error: Could not create %s",filename);
+	perror(errormsg);
+	return 0;
       }
 
       // Data format :
@@ -2502,7 +2642,13 @@ int Profiler::DumpData(bool increment, int tid, char *prefix){
 
 	    while (current != 0){
 	      /* Traverse the stack */ 
-	      if ((*it) == current->ThisFunction){ /* Match! */
+
+#ifdef TAU_CALLPATH
+	      if ((*it) == current->ThisFunction || (*it) == current->CallPathFunction) {
+#else
+		if ((*it) == current->ThisFunction) { 
+#endif
+		  /* Match! */
 		DEBUGPROFMSG("MATCH! Name :"<<current->ThisFunction->GetName()
 			     <<endl;);
 
@@ -2541,12 +2687,11 @@ int Profiler::DumpData(bool increment, int tid, char *prefix){
 		       << (*it)->GetCalls(tid) << " Subrs : "<< (*it)->GetSubrs(tid)
 		       << " Excl : " << tmpDoubleExcl[i] << " Incl : "
 		       << tmpDoubleIncl[i] << endl;);
-	  
+
 	  fprintf(fp,"\"%s %s\" %ld %ld %.16G %.16G ", (*it)->GetName(),
 		  (*it)->GetType(), (*it)->GetCalls(tid), (*it)->GetSubrs(tid),
 		  tmpDoubleExcl[i], tmpDoubleIncl[i]);
-	}
-	else{
+	} else {
 	  DEBUGPROFMSG("Node: "<< RtsLayer::myNode() <<  " Dumping "
 		       << (*it)->GetName()<< " "  << (*it)->GetType() << " Calls : "
 		       << (*it)->GetCalls(tid) << " Subrs : "<< (*it)->GetSubrs(tid)
@@ -2758,7 +2903,7 @@ void Profiler::CallStackTrace(int tid)
     if (curr->AddInclFlag == true)
     {
       // calculate inclusive time for profiler's FunctionInfo
-      curr->ThisFunction->InclTime_cs = curr->ThisFunction->GetInclTime()  
+      curr->ThisFunction->InclTime_cs = curr->ThisFunction->GetInclTime(tid)  
                                       + totalTime;
     }
     
@@ -2848,12 +2993,21 @@ void Profiler::AddNumChildren(long value)
 }
 #endif /* TAU_COMPENSATE */
 
+//////////////////////////////////////////////////////////////////////
+//  Profiler::GetPhase(void)
+//  Description: Returns if a profiler is a phase or not 
+//////////////////////////////////////////////////////////////////////
 #ifdef TAU_PROFILEPHASE
 bool Profiler::GetPhase(void)
 {
   return PhaseFlag;
 }
 
+//////////////////////////////////////////////////////////////////////
+//  Profiler::GetPhase(bool flag)
+//  Description: SetPhase sets a phase to be true or false based on the 
+//               parameter flag
+//////////////////////////////////////////////////////////////////////
 void Profiler::SetPhase(bool flag)
 {
   PhaseFlag = flag;
@@ -2862,22 +3016,106 @@ void Profiler::SetPhase(bool flag)
 #endif /* TAU_PROFILEPHASE */
 
 #ifdef TAU_DEPTH_LIMIT 
+//////////////////////////////////////////////////////////////////////
+//  Profiler::GetDepthLimit(void)
+//  Description: GetDepthLimit returns the callstack depth beyond which
+//               all instrumentation is disabled
+//////////////////////////////////////////////////////////////////////
 int Profiler::GetDepthLimit(void)
 {
   return profiledepth;
 }
 
+//////////////////////////////////////////////////////////////////////
+//  Profiler::SetDepthLimit(int value)
+//  Description: SetDepthLimit sets the callstack instrumentation depth
+//////////////////////////////////////////////////////////////////////
 void Profiler::SetDepthLimit(int value)
 {
   profiledepth = value;
 }
 #endif /* TAU_DEPTH_LIMIT */ 
 
+//////////////////////////////////////////////////////////////////////
+//  TauGetThrottle(void)
+//  Description: Returns whether throttling is enabled or disabled 
+//////////////////////////////////////////////////////////////////////
+bool TauGetThrottle(void)
+{
+  if (getenv("TAU_THROTTLE") == (char *) NULL)
+   return false;
+  else
+   return true;
+}
 
+
+//////////////////////////////////////////////////////////////////////
+//  TauGetThrottleNumCalls(void)
+//  Description: Returns (as a double) the number of calls for throttle
+//               based control of instrumentation. 
+//////////////////////////////////////////////////////////////////////
+double TauGetThrottleNumCalls(void)
+{
+  char *numcalls = getenv("TAU_THROTTLE_NUMCALLS"); 
+  double d = TAU_THROTTLE_NUMCALLS_DEFAULT;  /* default numcalls */
+  if (numcalls)
+  {
+    d = strtod(numcalls,0); 
+  }
+  DEBUGPROFMSG("TauGetThrottleNumCalls: Returning "<<d <<" as numcalls value"<<endl;);
+  return d;
+}
+
+//////////////////////////////////////////////////////////////////////
+//  TauGetThrottlePerCall(void)
+//  Description: Returns (as a double) the per call value for throttle
+//               based control of instrumentation. 
+//////////////////////////////////////////////////////////////////////
+double TauGetThrottlePerCall(void)
+{
+  char *percall = getenv("TAU_THROTTLE_PERCALL"); 
+  double d = TAU_THROTTLE_PERCALL_DEFAULT;  /* default numcalls */
+  if (percall)
+  {
+    d = strtod(percall,0); 
+  }
+  DEBUGPROFMSG("TauGetThrottlePerCall: Returning "<<d <<" as per-call value"<<endl;);
+  return d;
+}
+
+//////////////////////////////////////////////////////////////////////
+//  Profiler::TheTauThrottle(void)
+//  Description: Returns whether throttling is enabled or disabled
+//////////////////////////////////////////////////////////////////////
+bool& Profiler::TheTauThrottle(void)
+{
+  static bool throttle = TauGetThrottle();
+  return throttle;
+}
+
+//////////////////////////////////////////////////////////////////////
+//  Profiler::TauGetThrottlePerCall(void)
+//  Description: Returns the number of calls for throttling
+//////////////////////////////////////////////////////////////////////
+double& Profiler::TheTauThrottleNumCalls(void)
+{
+  static double throttleNumcalls = TauGetThrottleNumCalls();
+  return throttleNumcalls;
+}
+
+//////////////////////////////////////////////////////////////////////
+//  Profiler::TauGetThrottlePerCall(void)
+//  Description: Returns the per call value for throttling
+//////////////////////////////////////////////////////////////////////
+double& Profiler::TheTauThrottlePerCall(void)
+{
+  static double throttlePercall = TauGetThrottlePerCall();
+  return throttlePercall;
+}
 /***************************************************************************
  * $RCSfile: Profiler.cpp,v $   $Author: sameer $
- * $Revision: 1.116 $   $Date: 2005/08/11 02:10:41 $
- * POOMA_VERSION_ID: $Id: Profiler.cpp,v 1.116 2005/08/11 02:10:41 sameer Exp $ 
+ * $Revision: 1.132 $   $Date: 2005/11/11 18:27:00 $
+ * POOMA_VERSION_ID: $Id: Profiler.cpp,v 1.132 2005/11/11 18:27:00 sameer Exp $ 
  ***************************************************************************/
 
 	
