@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1997  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -23,7 +23,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 
 
@@ -1256,6 +1256,9 @@ int RtsLayer::MergeAndConvertTracesIfNecessary(void)
 
       /* and execute it */
 #ifndef TAU_CATAMOUNT
+/* NOTE: BGL will not execute this code as well because the compute node 
+   kernels cannot fork tasks. So, on BGL, nothing will happen when the 
+   following system command executes */
       system(cmd);
 #endif /* TAU_CATAMOUNT */
     } /* on node 0, thread 0 */
@@ -1293,6 +1296,6 @@ std::string RtsLayer::GetRTTI(const char *name)
 
 /***************************************************************************
  * $RCSfile: RtsLayer.cpp,v $   $Author: amorris $
- * $Revision: 1.67 $   $Date: 2005/07/29 21:44:05 $
- * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.67 2005/07/29 21:44:05 amorris Exp $ 
+ * $Revision: 1.69 $   $Date: 2005/11/11 03:46:49 $
+ * POOMA_VERSION_ID: $Id: RtsLayer.cpp,v 1.69 2005/11/11 03:46:49 amorris Exp $ 
  ***************************************************************************/
