@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1997  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -23,7 +23,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 
 #ifdef TAU_DOT_H_LESS_HEADERS 
@@ -146,7 +146,7 @@ extern "C" void Tau_set_context(int context)
 }
 
 ///////////////////////////////////////////////////////////////////////////
-extern "C" void Tau_callstack(void)
+extern "C" void Tau_profile_callstack(void)
 {
   TAU_PROFILE_CALLSTACK();
 }
@@ -691,8 +691,8 @@ extern "C" void Tau_mark_group_as_phase(void **ptr)
 }
 
 /***************************************************************************
- * $RCSfile: TauCAPI.cpp,v $   $Author: sameer $
- * $Revision: 1.52 $   $Date: 2005/08/11 02:23:45 $
- * VERSION: $Id: TauCAPI.cpp,v 1.52 2005/08/11 02:23:45 sameer Exp $
+ * $RCSfile: TauCAPI.cpp,v $   $Author: amorris $
+ * $Revision: 1.54 $   $Date: 2005/11/11 03:46:49 $
+ * VERSION: $Id: TauCAPI.cpp,v 1.54 2005/11/11 03:46:49 amorris Exp $
  ***************************************************************************/
 
