@@ -1,6 +1,6 @@
 /****************************************************************************
 **			TAU Portable Profiling Package			   **
-**			http://www.acl.lanl.gov/tau		           **
+**			http://www.cs.uoregon.edu/research/tau	           **
 *****************************************************************************
 **    Copyright 1997  						   	   **
 **    Department of Computer and Information Science, University of Oregon **
@@ -23,7 +23,7 @@
 **			  -DPOOMA_KAI for KCC compiler 			  **
 **			  -DDEBUG_PROF  for internal debugging messages   **
 **                        -DPROFILE_CALLSTACK to enable callstack traces  **
-**	Documentation	: See http://www.acl.lanl.gov/tau	          **
+**	Documentation	: See http://www.cs.uoregon.edu/research/tau      **
 ***************************************************************************/
 
 /* Fortran Wrapper layer for TAU Portable Profiling */
@@ -80,6 +80,7 @@ void Tau_track_memory_headroom_here(void);
 void Tau_enable_tracking_memory_headroom(void);
 void Tau_disable_tracking_memory_headroom(void);
 void Tau_mark_group_as_phase(void **ptr);
+void Tau_profile_callstack(void );
 
 
 
@@ -164,10 +165,17 @@ void tau_profile_timer_(void **ptr, char *fname, int flen)
   
 
 #ifdef DEBUG_PROF
-  printf("Inside tau_profile_timer_ fname=%s\n", infname);
+  printf("Inside tau_profile_timer_ fname=%s\n", fname);
 #endif /* DEBUG_PROF */
   if (*ptr == 0) 
   {
+
+#ifdef TAU_OPENMP
+#pragma omp critical
+    {
+      if (*ptr == 0) {
+#endif /* TAU_OPENMP */
+
     // make a copy so that we can null terminate it
     char *localname = (char *) malloc((size_t)flen+1);
     // hold on to the original pointer to free it since EXTRACT_GROUP
@@ -187,6 +195,12 @@ void tau_profile_timer_(void **ptr, char *fname, int flen)
     EXTRACT_GROUP(localname, flen, gr, gr_name)
     *ptr = Tau_get_profiler(localname, (char *)" ", gr, gr_name);
     free(tmp); 
+
+#ifdef TAU_OPENMP
+      }
+    }
+#endif /* TAU_OPENMP */
+
   }
 
 #ifdef DEBUG_PROF 
@@ -966,7 +980,7 @@ void tau_context_event(int **ptr, double *data)
 //#endif /* TAU_XLC || TAU_AIX || HP_FORTRAN */
 
 
-#if (defined (TAU_GNU) || defined (TAU_PATHSCALE))
+#if (defined (TAU_GNU) || defined (TAU_PATHSCALE) || defined (TAU_OPEN64ORC))
 
 void tau_profile_timer__(void **ptr, char *fname, int flen)
 {
@@ -1293,10 +1307,31 @@ void TAU_PHASE_STOP(void **profiler)
   tau_phase_stop_(profiler);
 }
 
+void tau_profile_callstack_(void)
+{
+  Tau_profile_callstack();
+}
+
+void tau_profile_callstack(void)
+{
+  tau_profile_callstack_();
+}
+
+void tau_profile_callstack__(void)
+{
+  tau_profile_callstack_();
+}
+
+void TAU_PROFILE_CALLSTACK(void)
+{
+  tau_profile_callstack_();
+}
+
 } /* extern "C" */
 
+
 /***************************************************************************
  * $RCSfile: TauFAPI.cpp,v $   $Author: amorris $
- * $Revision: 1.45 $   $Date: 2005/08/22 17:02:05 $
- * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.45 2005/08/22 17:02:05 amorris Exp $ 
+ * $Revision: 1.50 $   $Date: 2005/11/11 03:46:49 $
+ * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.50 2005/11/11 03:46:49 amorris Exp $ 
  ***************************************************************************/
