@@ -1,16 +1,18 @@
 package client;
 
 import javax.swing.*;
+
 import java.awt.event.*;
 import java.util.List;
+import java.util.ArrayList;
 import java.util.ListIterator;
-import edu.uoregon.tau.dms.dss.*;
+import edu.uoregon.tau.perfdmf.*;
+import constants.Constants;
 import common.RMIView;
 import common.RMIPerfExplorerModel;
 
 public class PerfExplorerActionListener implements ActionListener {
 
-	private static final String VERSION = "Built on XXXXX";
 	public final static String QUIT = "Quit PerfExplorer";
 	public final static String QUIT_SERVER = "Quit PerfExplorer (Shutdown Server)";
 	public final static String ABOUT = "About PerfExplorer";
@@ -26,6 +28,7 @@ public class PerfExplorerActionListener implements ActionListener {
 	public final static String DO_VARIATION_ANALYSIS = "Show Data Summary";
 	// chart menu items
 	public final static String SET_GROUPNAME = "Set Group Name";
+	public final static String SET_PROBLEM_SIZE = "Set Problem Size (Scaling)";
 	public final static String SET_METRICNAME = "Set Metric of Interest";
 	public final static String SET_TIMESTEPS = "Set Total Number of Timesteps";
 	public final static String SET_EVENTNAME = "Set Event of Interest";
@@ -38,6 +41,7 @@ public class PerfExplorerActionListener implements ActionListener {
 	public final static String SPEEDUP_ONE_EVENT_CHART = "Relative Speedup for One Event";
 	public final static String COMMUNICATION_CHART = "Group % of Total Runtime";
 	public final static String FRACTION_CHART = "Runtime Breakdown";
+	public final static String CORRELATION_CHART = "Correlate Events with Total Runtime";
 	// phase chart menu items
 	public final static String EFFICIENCY_PHASE_CHART = "Relative Efficiency per Phase";
 	public final static String SPEEDUP_PHASE_CHART = "Relative Speedup per Phase";
@@ -45,6 +49,8 @@ public class PerfExplorerActionListener implements ActionListener {
 	// arbitrary view menu items
 	public final static String CREATE_NEW_VIEW = "Create New View";
 	public final static String CREATE_NEW_SUB_VIEW = "Create New Sub-view";
+	public final static String DO_IQR_BOXCHART = "Create BoxChart";
+	public final static String DO_HISTOGRAM = "Create Histograms";
 
 	private PerfExplorerClient mainFrame;
 
@@ -87,10 +93,18 @@ public class PerfExplorerActionListener implements ActionListener {
 				} else if (arg.equals(DO_CORRELATION_CUBE)) {
 					if (valid3DSelection())
 						PerfExplorerCube.doCorrelationCube();
+				} else if (arg.equals(DO_IQR_BOXCHART)) {
+					if (valid3DSelection())
+						PerfExplorerBoxChart.doIQRBoxChart();
+				} else if (arg.equals(DO_HISTOGRAM)) {
+					if (valid3DSelection())
+						PerfExplorerHistogramChart.doHistogram();
 				} else if (arg.equals(DO_VARIATION_ANALYSIS)) {
 					if (valid3DSelection())
 						PerfExplorerVariation.doVariationAnalysis();
 			// chart items
+				} else if (arg.equals(SET_PROBLEM_SIZE)) {
+					checkAndSetProblemSize(true);
 				} else if (arg.equals(SET_GROUPNAME)) {
 					checkAndSetGroupName(true);
 				} else if (arg.equals(SET_METRICNAME)) {
@@ -105,23 +119,29 @@ public class PerfExplorerActionListener implements ActionListener {
 							PerfExplorerChart.doTimestepsChart();
 				} else if (arg.equals(EFFICIENCY_CHART)) {
 					if (checkAndSetMetricName(false))
-						PerfExplorerChart.doEfficiencyChart();
+						if (checkAndSetProblemSize(false))
+							PerfExplorerChart.doEfficiencyChart();
 				} else if (arg.equals(EFFICIENCY_EVENTS_CHART)) {
 					if (checkAndSetMetricName(false))
+						if (checkAndSetProblemSize(false))
 						PerfExplorerChart.doEfficiencyEventsChart();
 				} else if (arg.equals(EFFICIENCY_ONE_EVENT_CHART)) {
 					if (checkAndSetMetricName(false))
 						if (checkAndSetEventName(false))
+						if (checkAndSetProblemSize(false))
 							PerfExplorerChart.doEfficiencyOneEventChart();
 				} else if (arg.equals(SPEEDUP_CHART)) {
 					if (checkAndSetMetricName(false))
+						if (checkAndSetProblemSize(false))
 						PerfExplorerChart.doSpeedupChart();
 				} else if (arg.equals(SPEEDUP_EVENTS_CHART)) {
 					if (checkAndSetMetricName(false))
+						if (checkAndSetProblemSize(false))
 						PerfExplorerChart.doSpeedupEventsChart();
 				} else if (arg.equals(SPEEDUP_ONE_EVENT_CHART)) {
 					if (checkAndSetMetricName(false))
 						if (checkAndSetEventName(false))
+						if (checkAndSetProblemSize(false))
 							PerfExplorerChart.doSpeedupOneEventChart();
 				} else if (arg.equals(COMMUNICATION_CHART)) {
 					if (checkAndSetMetricName(false))
@@ -130,11 +150,17 @@ public class PerfExplorerActionListener implements ActionListener {
 				} else if (arg.equals(FRACTION_CHART)) {
 					if (checkAndSetMetricName(false))
 						PerfExplorerChart.doFractionChart();
+				} else if (arg.equals(CORRELATION_CHART)) {
+					if (checkAndSetMetricName(false))
+						//if (checkAndSetProblemSize(false))
+							PerfExplorerChart.doCorrelationChart();
 				} else if (arg.equals(EFFICIENCY_PHASE_CHART)) {
 					if (checkAndSetMetricName(false))
+						if (checkAndSetProblemSize(false))
 						PerfExplorerChart.doEfficiencyPhasesChart();
 				} else if (arg.equals(SPEEDUP_PHASE_CHART)) {
 					if (checkAndSetMetricName(false))
+						if (checkAndSetProblemSize(false))
 						PerfExplorerChart.doSpeedupPhasesChart();
 				} else if (arg.equals(FRACTION_PHASE_CHART)) {
 					if (checkAndSetMetricName(false))
@@ -156,7 +182,7 @@ public class PerfExplorerActionListener implements ActionListener {
 	}
 
     public static String getVersionString() {
-		return new String(VERSION);
+		return new String(Constants.VERSION);
 	}
 
 	public void createAboutWindow() {
@@ -222,7 +248,7 @@ public class PerfExplorerActionListener implements ActionListener {
 	public void createClusterSizeWindow() {
 		String numClusters = (new Integer(PerfExplorerModel.getModel().getNumberOfClusters())).toString();
 		String reply = (String)JOptionPane.showInputDialog (mainFrame,
-			"Enter the max number of clusters (<= " + PerfExplorerModel.MAX_CLUSTERS + "):",
+			"Enter the max number of clusters (<= " + numClusters + "):",
 			"Max Clusters", JOptionPane.PLAIN_MESSAGE);
 		if (reply != null && !reply.equals(""))
 			PerfExplorerModel.getModel().setNumberOfClusters(reply);
@@ -358,7 +384,7 @@ public class PerfExplorerActionListener implements ActionListener {
 		Object selection = theModel.getCurrentSelection();
 		String status = null;
 		if ((selection instanceof Trial) || (selection instanceof Metric)) {
-			String tmp = theModel.getClusterMethod();
+//			String tmp = theModel.getClusterMethod();
 			RMIPerfExplorerModel modelCopy = theModel.copy();
 			modelCopy.setClusterMethod(PerfExplorerModel.CORRELATION_ANALYSIS);
 			int reply = getConfirmation(modelCopy);
@@ -532,4 +558,22 @@ public class PerfExplorerActionListener implements ActionListener {
 		}
 		return (!forceIt && timesteps == null) ? false : true;
 	}
+
+	private boolean checkAndSetProblemSize (boolean forceIt) {
+		PerfExplorerModel theModel = PerfExplorerModel.getModel();
+		Boolean constantProblem = theModel.getConstantProblem();
+		if (forceIt || constantProblem == null) {
+			List answers = new ArrayList();
+			answers.add("Yes, the problem size remains constant.");
+			answers.add("No, the problem increases as the processor count increases.");
+			Object[] options = answers.toArray();
+			String response = (String)JOptionPane.showInputDialog (mainFrame,
+				"Does the problem size remain constant, or does it scale with the number of processors?",
+				"Problem Scaling", JOptionPane.PLAIN_MESSAGE,
+				null, options, options[0]);
+			theModel.setConstantProblem(response.startsWith("Y") ? true : false);
+			constantProblem = theModel.getConstantProblem();
+		}
+		return (!forceIt && constantProblem == null) ? false : true;
+	}
 }
