@@ -2,21 +2,38 @@ package client;
 
 import common.RMIChartData;
 import java.awt.*;
+import java.awt.event.*;
+import java.awt.BasicStroke;
+import javax.swing.JFrame;
+import javax.swing.JMenuItem;
+import javax.swing.JOptionPane;
 import java.util.List;
 import org.jfree.chart.ChartFactory;
-import org.jfree.chart.ChartFrame;
+import org.jfree.chart.ChartPanel;
 import org.jfree.chart.JFreeChart;
 import org.jfree.chart.plot.PlotOrientation;
 import org.jfree.data.xy.DefaultTableXYDataset;
 import org.jfree.data.xy.XYSeriesCollection;
 import org.jfree.data.xy.XYSeries;
+import org.jfree.data.xy.XYDataset;
+import org.jfree.chart.axis.NumberAxis;
+import org.jfree.chart.renderer.xy.StandardXYItemRenderer;
+import org.jfree.chart.renderer.xy.XYItemRenderer;
 import org.jfree.chart.plot.XYPlot;
 import org.jfree.chart.StandardLegend;
 import org.jfree.chart.renderer.xy.XYLineAndShapeRenderer;
+import org.jfree.chart.labels.StandardXYToolTipGenerator;
+import java.text.DecimalFormat;
+import edu.uoregon.tau.common.ImageExport;
+import edu.uoregon.tau.common.VectorExport;
 
-public class PerfExplorerChart {
+public class PerfExplorerChart extends PerfExplorerChartWindow {
 
-	public static void doFractionChart () {
+	public PerfExplorerChart (JFreeChart chart, String name) {
+		super(chart, name);
+	}
+
+	public static PerfExplorerChart doFractionChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -47,14 +64,58 @@ public class PerfExplorerChart {
             true,                            // tooltips
             false                            // urls
         );
-		ChartFrame frame = new ChartFrame("Total Runtime Breakdown", chart);
-		centerFrame(frame);
 
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Total Runtime Breakdown");
 	}
 
-	public static void doEfficiencyChart () {
+	public static PerfExplorerChart doCorrelationChart () {
+		// get the server
+		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
+		// get the data
+		RMIChartData rawData = server.requestChartData(
+			PerfExplorerModel.getModel(), RMIChartData.CORRELATION_DATA);
+
+        XYDataset dataset = new CorrelationPlotDataset(rawData, false);
+        //JFreeChart chart = ChartFactory.createScatterPlot(
+        JFreeChart chart = ChartFactory.createXYLineChart(
+            "Correlation Results",  // chart title
+            //"Inclusive Time for " + (String)rawData.getRowLabels().get(0), //domain axis
+            "Processors", //domain axis
+            "Exclusive Time for Event",  // range axis
+            dataset,					// data
+            PlotOrientation.VERTICAL,		// the orientation
+            true,						// legend
+            false,						// tooltips
+            false						// urls
+        );
+
+		customizeChart(chart, rawData.getRows(), true);
+        XYPlot plot = chart.getXYPlot();
+        NumberAxis axis2 = new NumberAxis("Inclusive Time for " + (String)rawData.getRowLabels().get(0));
+        axis2.setAutoRangeIncludesZero(false);
+        plot.setRangeAxis(1, axis2);
+        XYDataset dataset2 = new CorrelationPlotDataset(rawData, true);
+        plot.setDataset(1, dataset2);
+        plot.mapDatasetToRangeAxis(1, 1);
+        StandardXYItemRenderer renderer2 = new StandardXYItemRenderer();
+        renderer2.setSeriesPaint(0, Color.black);
+        renderer2.setPlotShapes(true);
+        renderer2.setSeriesStroke(
+            0, new BasicStroke(
+                2.0f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND,
+                1.0f, new float[] {10.0f, 6.0f}, 0.0f
+            )
+        );
+		renderer2.setToolTipGenerator(new StandardXYToolTipGenerator(
+			StandardXYToolTipGenerator.DEFAULT_TOOL_TIP_FORMAT,
+			new DecimalFormat("processors: #######"), 
+			new DecimalFormat("value: #,##0.00")));
+
+        plot.setRenderer(1, renderer2);
+		return new PerfExplorerChart(chart, "Total Runtime Breakdown");
+	}
+
+	public static PerfExplorerChart doEfficiencyChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -68,13 +129,16 @@ public class PerfExplorerChart {
 		for (int y = 0 ; y < rawData.getRows() ; y++) {
 			List row = rawData.getRowData(y);
         	XYSeries s = new XYSeries((String)rowLabels.get(y), true, false);
-			double[] baseline = (double[])(row.get(0));
-			for (int x = 0 ; x < row.size() ; x++) {
-				double[] values = (double[])(row.get(x));
-				ratio = baseline[0]/values[0];
-				ideal = baseline[1] * ratio;
-        		s.add(values[0], ideal/values[1]);
-			}
+				double[] baseline = (double[])(row.get(0));
+				for (int x = 0 ; x < row.size() ; x++) {
+					double[] values = (double[])(row.get(x));
+					ratio = baseline[0]/values[0];
+					if (PerfExplorerModel.getModel().getConstantProblem().booleanValue())
+						ideal = baseline[1] * ratio;
+					else 
+						ideal = baseline[1];
+        			s.add(values[0], ideal/values[1]);
+				}
         	dataset.addSeries(s);
 		}
 
@@ -91,13 +155,10 @@ public class PerfExplorerChart {
             false                            // urls
         );
 		customizeChart(chart, rawData.getRows(), false);
-		ChartFrame frame = new ChartFrame("Relative Efficiency", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Relative Efficiency");
 	}
 
-	public static void doEfficiencyEventsChart () {
+	public static PerfExplorerChart doEfficiencyEventsChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -115,7 +176,10 @@ public class PerfExplorerChart {
 			for (int x = 0 ; x < row.size() ; x++) {
 				double[] values = (double[])(row.get(x));
 				ratio = baseline[0]/values[0];
-				ideal = baseline[1] * ratio;
+				if (PerfExplorerModel.getModel().getConstantProblem().booleanValue())
+					ideal = baseline[1] * ratio;
+				else 
+					ideal = baseline[1];
         		s.add(values[0], ideal/values[1]);
 			}
         	dataset.addSeries(s);
@@ -134,13 +198,10 @@ public class PerfExplorerChart {
             false                            // urls
         );
 		customizeChart(chart, rawData.getRows(), false);
-		ChartFrame frame = new ChartFrame("Relative Efficiency by Event", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Relative Efficiency by Event");
 	}
 
-	public static void doEfficiencyOneEventChart () {
+	public static PerfExplorerChart doEfficiencyOneEventChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -158,7 +219,10 @@ public class PerfExplorerChart {
 			for (int x = 0 ; x < row.size() ; x++) {
 				double[] values = (double[])(row.get(x));
 				ratio = baseline[0]/values[0];
-				ideal = baseline[1] * ratio;
+				if (PerfExplorerModel.getModel().getConstantProblem().booleanValue())
+					ideal = baseline[1] * ratio;
+				else 
+					ideal = baseline[1];
         		s.add(values[0], ideal/values[1]);
 			}
         	dataset.addSeries(s);
@@ -177,13 +241,10 @@ public class PerfExplorerChart {
             false                            // urls
         );
 		customizeChart(chart, rawData.getRows(), false);
-		ChartFrame frame = new ChartFrame("Relative Efficiency for Event", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Relative Efficiency for Event");
 	}
 
-	public static void doSpeedupChart () {
+	public static PerfExplorerChart doSpeedupChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -203,7 +264,10 @@ public class PerfExplorerChart {
 			for (int x = 0 ; x < row.size() ; x++) {
 				double[] values = (double[])(row.get(x));
 				ratio = baseline[0]/values[0];
-				ideal = baseline[1] * ratio;
+				if (PerfExplorerModel.getModel().getConstantProblem().booleanValue())
+					ideal = baseline[1] * ratio;
+				else 
+					ideal = baseline[1];
 				efficiency = ideal/values[1];
 				// System.out.println("adding: " + values[0] + ", " + efficiency/ratio);
         		s.add(values[0], efficiency / ratio);
@@ -232,13 +296,10 @@ public class PerfExplorerChart {
             false                            // urls
         );
 		customizeChart(chart, rawData.getRows(), true);
-		ChartFrame frame = new ChartFrame("Relative Speedup", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Relative Speedup");
 	}
 
-	public static void doSpeedupEventsChart () {
+	public static PerfExplorerChart doSpeedupEventsChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -257,7 +318,10 @@ public class PerfExplorerChart {
 			for (int x = 0 ; x < row.size() ; x++) {
 				double[] values = (double[])(row.get(x));
 				ratio = baseline[0]/values[0];
-				ideal = baseline[1] * ratio;
+				if (PerfExplorerModel.getModel().getConstantProblem().booleanValue())
+					ideal = baseline[1] * ratio;
+				else 
+					ideal = baseline[1];
 				efficiency = ideal/values[1];
         		s.add(values[0], efficiency / ratio);
 				if (maxx < values[0])
@@ -285,13 +349,10 @@ public class PerfExplorerChart {
             false                            // urls
         );
 		customizeChart(chart, rawData.getRows(), true);
-		ChartFrame frame = new ChartFrame("Relative Speedup by Event", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Relative Speedup by Event");
 	}
 
-	public static void doSpeedupOneEventChart () {
+	public static PerfExplorerChart doSpeedupOneEventChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -310,7 +371,10 @@ public class PerfExplorerChart {
 			for (int x = 0 ; x < row.size() ; x++) {
 				double[] values = (double[])(row.get(x));
 				ratio = baseline[0]/values[0];
-				ideal = baseline[1] * ratio;
+				if (PerfExplorerModel.getModel().getConstantProblem().booleanValue())
+					ideal = baseline[1] * ratio;
+				else 
+					ideal = baseline[1];
 				efficiency = ideal/values[1];
         		s.add(values[0], efficiency / ratio);
 				if (maxx < values[0])
@@ -338,14 +402,11 @@ public class PerfExplorerChart {
             false                            // urls
         );
 		customizeChart(chart, rawData.getRows(), true);
-		ChartFrame frame = new ChartFrame("Relative Speedup for Event", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Relative Speedup for Event");
 	}
 
 
-	public static void doTimestepsChart () {
+	public static PerfExplorerChart doTimestepsChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -379,13 +440,10 @@ public class PerfExplorerChart {
         );
 
 		customizeChart(chart, rawData.getRows(), false);
-		ChartFrame frame = new ChartFrame("Timesteps per Second", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Timesteps per Second");
 	}
 
-	public static void doCommunicationChart () {
+	public static PerfExplorerChart doCommunicationChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -412,7 +470,8 @@ public class PerfExplorerChart {
 		}
 
         JFreeChart chart = ChartFactory.createXYLineChart(
-            "Communication Time / Total Runtime" +   // chart title
+            PerfExplorerModel.getModel().getGroupName() + 
+			" Time / Total Runtime - " +   // chart title
 			PerfExplorerModel.getModel().toString() + ":" +
 			PerfExplorerModel.getModel().getMetricName(),
             "Number of Processors",          // domain axis label
@@ -425,13 +484,10 @@ public class PerfExplorerChart {
         );
 
 		customizeChart(chart, rawData1.getRows(), false);
-		ChartFrame frame = new ChartFrame("Transpose Time / Total Runtime", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, PerfExplorerModel.getModel().getGroupName() + " Time / Total Runtime");
 	}
 
-	public static void doEfficiencyPhasesChart () {
+	public static PerfExplorerChart doEfficiencyPhasesChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -468,13 +524,10 @@ public class PerfExplorerChart {
             false                            // urls
         );
 		customizeChart(chart, rawData.getRows(), false);
-		ChartFrame frame = new ChartFrame("Relative Efficiency by Event", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Relative Efficiency by Event");
 	}
 
-	public static void doSpeedupPhasesChart () {
+	public static PerfExplorerChart doSpeedupPhasesChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -522,13 +575,10 @@ public class PerfExplorerChart {
             false                            // urls
         );
 		customizeChart(chart, rawData.getRows(), true);
-		ChartFrame frame = new ChartFrame("Relative Speedup by Event", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Relative Speedup by Event");
 	}
 
-	public static void doFractionPhasesChart () {
+	public static PerfExplorerChart doFractionPhasesChart () {
 		// get the server
 		PerfExplorerConnection server = PerfExplorerConnection.getConnection();
 		// get the data
@@ -560,10 +610,7 @@ public class PerfExplorerChart {
             true,                            // tooltips
             false                            // urls
         );
-		ChartFrame frame = new ChartFrame("Total Runtime Breakdown", chart);
-		centerFrame(frame);
-		frame.pack();
-		frame.setVisible(true);
+		return new PerfExplorerChart(chart, "Total Runtime Breakdown");
 	}
 
 
@@ -584,6 +631,18 @@ public class PerfExplorerChart {
         renderer.setDefaultShapesFilled(true);
         //renderer.setPlotShapes(true);
         renderer.setItemLabelsVisible(true);
+		renderer.setToolTipGenerator(
+			new StandardXYToolTipGenerator(
+				StandardXYToolTipGenerator.DEFAULT_TOOL_TIP_FORMAT,
+					new DecimalFormat("processors: #######"), new DecimalFormat("value: #,##0.00")));
+
+        //renderer.setToolTipGenerator(new XYToolTipGenerator() {
+            //public String generateToolTip(XYDataset dataset, int arg1, int arg2) {
+                //return "<html>Number of threads: " + (int)dataset.getXValue(arg1, arg2) + 
+                //"<BR>Value: " + dataset.getYValue(arg1, arg2) + "</html>";
+            //}
+        //});
+
 
 		for (int i = 0 ; i < rows ; i++) {
 			renderer.setSeriesStroke(i, new BasicStroke(2.0f));
@@ -601,26 +660,4 @@ public class PerfExplorerChart {
 
 	}
 
-	private static void centerFrame(ChartFrame frame) {
-        //Window Stuff.
-        int windowWidth = 700;
-        int windowHeight = 450;
-        
-        //Grab paraProfManager position and size.
-        Point parentPosition = PerfExplorerClient.getMainFrame().getLocationOnScreen();
-        Dimension parentSize = PerfExplorerClient.getMainFrame().getSize();
-        int parentWidth = parentSize.width;
-        int parentHeight = parentSize.height;
-        
-        //Set the window to come up in the center of the screen.
-        int xPosition = (parentWidth - windowWidth) / 2;
-        int yPosition = (parentHeight - windowHeight) / 2;
-
-        xPosition = (int) parentPosition.getX() + xPosition;
-        yPosition = (int) parentPosition.getY() + yPosition;
-
-        frame.setLocation(xPosition, yPosition);
-        frame.setSize(new java.awt.Dimension(windowWidth, windowHeight));
- 	}
-
 }
