@@ -4,16 +4,17 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import common.*;
-import edu.uoregon.tau.dms.dss.*;
-import edu.uoregon.tau.dms.database.*;
+import edu.uoregon.tau.perfdmf.*;
+import edu.uoregon.tau.perfdmf.database.*;
 import java.util.List;
+import java.util.ArrayList;
 
 /**
  * The ChartData class is used to select data from the database which 
  * represents the performance profile of the selected trials, and return them
  * in a format for JFreeChart to display them.
  *
- * <P>CVS $Id: ChartData.java,v 1.11 2005/08/12 00:23:01 khuck Exp $</P>
+ * <P>CVS $Id: ChartData.java,v 1.23 2005/11/11 17:32:13 khuck Exp $</P>
  * @author  Kevin Huck
  * @version 0.1
  * @since   0.1
@@ -25,7 +26,8 @@ public class ChartData extends RMIChartData {
 	private String groupName = null;
 	private String eventName = null;
 	private String groupByColumn = null;
-	
+	private boolean preQuery = false;
+	private List columnValues = null;
 	
 	/**
 	 * Constructor
@@ -72,28 +74,74 @@ public class ChartData extends RMIChartData {
 		PerfExplorerServer.getServer().getControl().WAIT("doQuery");
 		PreparedStatement statement = null;
 		try {
-			// all query results are organized the same, only the selection
-			// parameters are different.
-			statement = buildStatement();
-			//System.out.println(statement.toString());
-			ResultSet results = statement.executeQuery();
-			// TODO - this query assumes a scalability study...!
 			String groupingName = null;
 			String threadName = null;
 			double value = 0.0;
 			double numThreads = 0;
 			String currentExperiment = "";
 			int experimentIndex = -1;
+			if (dataType == CORRELATION_DATA) {
+				columnValues = new ArrayList();
+				preQuery = true;
+				// do a pre-query to get the event with inclusive value
+				// of 100.0.
+				statement = buildStatement();
+				//System.out.println(statement.toString());
+				ResultSet results = statement.executeQuery();
+				// TODO - this query assumes a scalability study...!
+				while (results.next() != false) {
+					groupingName = results.getString(1);
+					threadName = results.getString(2);
+					numThreads = results.getDouble(2);
+					value = results.getDouble(3);
+					if (metricName.toLowerCase().indexOf("time") != -1)
+						value = value/1000000;
+	
+					if (!currentExperiment.equals(groupingName)) {
+						experimentIndex++;
+						currentExperiment = groupingName;
+						addRow(groupingName);
+					}
+					addColumn(experimentIndex, numThreads, value);
+					columnValues.add(new Double(numThreads));
+				} 
+				results.close();
+				statement.close();
+				preQuery = false;
+			}
+			// all query results are organized the same, only the selection
+			// parameters are different.
+			statement = buildStatement();
+			//System.out.println(statement.toString());
+			ResultSet results = statement.executeQuery();
+			// TODO - this query assumes a scalability study...!
+			int columnCounter = 0;
 			while (results.next() != false) {
 				groupingName = results.getString(1);
 				threadName = results.getString(2);
 				numThreads = results.getDouble(2);
 				value = results.getDouble(3);
+				if ((metricName.toLowerCase().indexOf("time") != -1) 
+					&& (dataType != FRACTION_OF_TOTAL))
+					value = value/1000000;
 
 				if (!currentExperiment.equals(groupingName)) {
 					experimentIndex++;
 					currentExperiment = groupingName;
 					addRow(groupingName);
+					columnCounter = 0;
+				}
+				// some methods may not have been called in the
+				// base case - MPI methods, for example
+				// add 0 values for those processor counts.
+				if (dataType == CORRELATION_DATA) {
+					Double mainThreads = (Double)columnValues.get(columnCounter);
+					while (mainThreads.doubleValue() < numThreads) {
+						addColumn(experimentIndex, mainThreads.doubleValue(), 0.0);
+						columnCounter++;
+						mainThreads = (Double)columnValues.get(columnCounter);
+					}
+					columnCounter++;
 				}
 				addColumn(experimentIndex, numThreads, value);
 			} 
@@ -110,6 +158,9 @@ public class ChartData extends RMIChartData {
 					threadName = results.getString(1);
 					numThreads = results.getDouble(1);
 					value = results.getDouble(2);
+					if ((metricName.toLowerCase().indexOf("time") != -1) 
+						&& (dataType != FRACTION_OF_TOTAL))
+						value = value/1000000;
 	
 					if (!currentExperiment.equals(groupingName)) {
 						experimentIndex++;
@@ -121,6 +172,23 @@ public class ChartData extends RMIChartData {
 				results.close();
 				statement.close();
 			}
+
+			try {
+				if ((dataType == RELATIVE_EFFICIENCY_EVENTS) || 
+					(dataType == CORRELATION_DATA)) {
+					DB db = PerfExplorerServer.getServer().getDB();
+					if (db.getDBType().compareTo("oracle") == 0) {
+						statement = db.prepareStatement("truncate table working_table");
+						statement.execute();
+						statement.close();
+					}
+					statement = db.prepareStatement("drop table working_table");
+					statement.execute();
+					statement.close();
+				}
+			} catch (Exception e) {
+				// do nothing, as all we did was truncate & drop the table
+			}
 		} catch (Exception e) {
 			System.out.println(statement.toString());
 			String error = "ERROR: Couldn't select the analysis settings from the database!";
@@ -144,14 +212,19 @@ public class ChartData extends RMIChartData {
 		PreparedStatement statement = null;
 		StringBuffer buf = new StringBuffer();
 		Object object = model.getCurrentSelection();
-		if (dataType == FRACTION_OF_TOTAL) {
+		if ((dataType == FRACTION_OF_TOTAL) ||
+			(dataType == CORRELATION_DATA && preQuery)) {
 			// The user wants to know the runtime breakdown by events of one 
 			// experiment as the number of threads of execution increases.
 
 			buf.append("select ie.name, ");
 
 			buf.append("(t.node_count * t.contexts_per_node * t.threads_per_context), ");
-			buf.append("ims.exclusive_percentage from interval_mean_summary ims ");
+			if (preQuery)
+				buf.append("ims.inclusive ");
+			else
+				buf.append("ims.exclusive_percentage ");
+			buf.append("from interval_mean_summary ims ");
 			buf.append("inner join interval_event ie ");
 			buf.append("on ims.interval_event = ie.id ");
 			buf.append("inner join trial t on ie.trial = t.id ");
@@ -165,15 +238,18 @@ public class ChartData extends RMIChartData {
 
 			buf.append(" and m.name = ? ");
 			
+			if (preQuery)
+				buf.append("and ims.inclusive_percentage = 100.0");
+			else {
+				buf.append("and ims.exclusive_percentage > ");
+				buf.append(model.getXPercent());
+			}
 
-//			buf.append("and ims.inclusive_percentage < 100.0 ");
-			buf.append("and ims.exclusive_percentage > 1.0 ");
-			buf.append("and (ie.group_name is null or (");
-
+			buf.append(" and (ie.group_name is null or (");
 			buf.append("ie.group_name not like '%TAU_CALLPATH%' ");
-			buf.append("and ie.group_name not like '%TAU_PHASE%')) order by 1, 2");
+			buf.append("and ie.group_name not like '%TAU_PHASE%')) ");
+			buf.append("order by 1, 2");
 
-			
 			statement = db.prepareStatement(buf.toString());
 			statement.setString(1, metricName);
 		} else if (dataType == RELATIVE_EFFICIENCY) {
@@ -225,7 +301,9 @@ public class ChartData extends RMIChartData {
 
 			buf.append(" and m.name = ? and ims.inclusive_percentage = 100.0 ");
 
-			buf.append(" and ie.group_name not like '%TAU_CALLPATH%' ");
+			buf.append(" and (ie.group_name is null or (");
+			buf.append("ie.group_name not like '%TAU_CALLPATH%' ");
+			buf.append("and ie.group_name not like '%TAU_PHASE%')) ");
 			//}
 			buf.append(" order by 1, 2");
 			statement = db.prepareStatement(buf.toString());
@@ -258,7 +336,7 @@ public class ChartData extends RMIChartData {
 
 			buf.append("inner join interval_event ie on ims.interval_event = ie.id ");
 			buf.append("inner join trial t on ie.trial = t.id ");
-			buf.append("inner join metric m on m.trial = t.id ");
+			buf.append("inner join metric m on m.id = ims.metric ");
 			buf.append("inner join experiment e on t.experiment = e.id ");
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, false));
@@ -300,20 +378,31 @@ public class ChartData extends RMIChartData {
 			statement = db.prepareStatement(buf.toString());
 			statement.setString(1, metricName);
 			statement.setString(2, groupName);
-		} else if (dataType == RELATIVE_EFFICIENCY_EVENTS) {
+		} else if ((dataType == RELATIVE_EFFICIENCY_EVENTS) ||
+			(dataType == CORRELATION_DATA && !preQuery)) {
 			// The user wants to know the relative efficiency or speedup
 			// of all the events for one experiment, as the number of threads of 
 			// execution increases.
-			buf.append("select ");
-			buf.append(" ie.name, ");
-			buf.append("(t.node_count * t.contexts_per_node * t.threads_per_context), ");
-
 			if (db.getDBType().compareTo("oracle") == 0) {
-				buf.append("ims.excl from interval_mean_summary ims ");
+				buf.append("create global temporary table working_table (name varchar2(4000)) ");
 			} else {
-				buf.append("ims.exclusive from interval_mean_summary ims ");
+				buf.append("create temporary table working_table (name text) ");
+			}
+			try {
+				statement = db.prepareStatement(buf.toString());
+				//System.out.println(statement.toString());
+				statement.execute();
+				statement.close();
+			} catch (Exception e) {
+				System.out.println(statement.toString());
+				String error = "ERROR: Couldn't select the analysis settings from the database!";
+				System.out.println(error);
+				e.printStackTrace();
 			}
 
+			buf = new StringBuffer();
+			buf.append("insert into working_table (select distinct ");
+			buf.append("ie.name from interval_mean_summary ims ");
 			buf.append("inner join interval_event ie on ims.interval_event = ie.id ");
 			buf.append("inner join trial t on ie.trial = t.id ");
 			buf.append("inner join metric m on m.id = ims.metric ");
@@ -323,14 +412,57 @@ public class ChartData extends RMIChartData {
 				buf.append("where t.experiment = ");
 				buf.append(model.getExperiment().getID() + " ");
 			}
-
 			buf.append(" and m.name = ? ");
-//			buf.append("and ims.inclusive_percentage < 100.0 ");
-			buf.append("and ims.exclusive_percentage > 1.0 ");
-			buf.append("and (ie.group_name is null or (");
+			buf.append("and ims.exclusive_percentage > ");
+			buf.append(model.getXPercent());
+			buf.append(" and (ie.group_name is null or (");
 			buf.append("ie.group_name not like '%TAU_CALLPATH%' ");
-			buf.append("and ie.group_name not like '%TAU_PHASE%')) order by 1, 2");
+			buf.append("and ie.group_name not like '%TAU_PHASE%')) ");
+			buf.append("and ims.inclusive_percentage < 100.0) ");
 
+			try {
+				statement = db.prepareStatement(buf.toString());
+				statement.setString(1, metricName);
+				//System.out.println(statement.toString());
+				statement.execute();
+				statement.close();
+			} catch (Exception e) {
+				System.out.println(statement.toString());
+				String error = "ERROR: Couldn't select the analysis settings from the database!";
+				System.out.println(error);
+				e.printStackTrace();
+			}
+
+			buf = new StringBuffer();
+			buf.append("select distinct ");
+			buf.append("ie.name, ");
+			buf.append("(t.node_count * t.contexts_per_node * t.threads_per_context), ");
+
+			if (dataType == CORRELATION_DATA) {
+				if (db.getDBType().compareTo("oracle") == 0) {
+					buf.append("ims.excl from interval_mean_summary ims ");
+				} else {
+					buf.append("ims.exclusive from interval_mean_summary ims ");
+				}
+			} else {
+				if (db.getDBType().compareTo("oracle") == 0) {
+					buf.append("ims.excl from interval_mean_summary ims ");
+				} else {
+					buf.append("ims.exclusive from interval_mean_summary ims ");
+				}
+			}
+			buf.append("inner join interval_event ie on ims.interval_event = ie.id ");
+			buf.append("inner join trial t on ie.trial = t.id ");
+			buf.append("inner join metric m on m.id = ims.metric ");
+			buf.append("inner join working_table w on w.name = ie.name ");
+			if (object instanceof RMIView) {
+				buf.append(model.getViewSelectionPath(true, true));
+			} else {
+				buf.append("where t.experiment = ");
+				buf.append(model.getExperiment().getID() + " ");
+			}
+
+			buf.append(" and m.name = ? order by 1, 2 ");
 			statement = db.prepareStatement(buf.toString());
 			statement.setString(1, metricName);
 		} else if (dataType == RELATIVE_EFFICIENCY_ONE_EVENT) {
@@ -348,7 +480,7 @@ public class ChartData extends RMIChartData {
 				buf.append(" e.name, ");
 			}
 			buf.append("(t.node_count * t.contexts_per_node * t.threads_per_context), ");
-			buf.append("inclusive from interval_mean_summary ims ");
+			buf.append("exclusive from interval_mean_summary ims ");
 			buf.append("inner join interval_event ie on ims.interval_event = ie.id ");
 			buf.append("inner join trial t on ie.trial = t.id ");
 			buf.append("inner join metric m on m.id = ims.metric ");
@@ -397,7 +529,7 @@ public class ChartData extends RMIChartData {
 			buf.append("ims.inclusive from interval_mean_summary ims ");
 			buf.append("inner join interval_event ie on ims.interval_event = ie.id ");
 			buf.append("inner join trial t on ie.trial = t.id ");
-			buf.append("inner join metric m on m.trial = t.id ");
+			buf.append("inner join metric m on m.id = ims.metric ");
 			buf.append("where t.experiment = ? and m.name = ? ");
 
 //			buf.append("and ims.inclusive_percentage < 100.0 ");
@@ -405,7 +537,8 @@ public class ChartData extends RMIChartData {
 			statement = db.prepareStatement(buf.toString());
 			statement.setInt (1, model.getExperiment().getID());
 			statement.setString(2, metricName);
-		} else if (dataType == FRACTION_OF_TOTAL_PHASES) {
+		} else if ((dataType == FRACTION_OF_TOTAL_PHASES) || 
+			(dataType == CORRELATION_DATA)) {
 			// The user wants to know the runtime breakdown by phases 
 			// of one experiment as the number of threads of execution
 			// increases.
@@ -423,7 +556,7 @@ public class ChartData extends RMIChartData {
 			buf.append("ims.inclusive_percentage from interval_mean_summary ims ");
 			buf.append("inner join interval_event ie on ims.interval_event = ie.id ");
 			buf.append("inner join trial t on ie.trial = t.id ");
-			buf.append("inner join metric m on m.trial = t.id ");
+			buf.append("inner join metric m on m.id = ims.metric ");
 			statement = null;
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true));
@@ -441,6 +574,40 @@ public class ChartData extends RMIChartData {
 
 			statement = db.prepareStatement(buf.toString());
 			statement.setString(1, metricName);
+		} else if (dataType == IQR_DATA) {
+			int contexts = 1;
+			int threads = 16;
+			// get the number of contexts and threads
+			
+			// The user wants to know the runtime breakdown by phases 
+			// of one experiment as the number of threads of execution
+			// increases.
+			buf.append("select ie.name, (p.node*");
+			buf.append(contexts * threads);
+			buf.append(") + (p.context*");
+			buf.append(threads);
+            
+            if (db.getDBType().compareTo("oracle") == 0) {
+                buf.append(") + p.thread as thread, p.excl ");
+            } else {
+                buf.append(") + p.thread as thread, p.exclusive_percentage ");
+            }
+
+			buf.append("from interval_event ie ");
+			buf.append("inner join interval_mean_summary s ");
+			buf.append("on ie.id = s.interval_event and s.exclusive_percentage > ");
+			buf.append(model.getXPercent());
+			buf.append(" left outer join interval_location_profile p ");
+			buf.append("on ie.id = p.interval_event ");
+			buf.append("and p.metric = s.metric where ie.trial = ? ");
+			buf.append(" and p.metric = ? ");
+			buf.append(" and (ie.group_name is null or (");
+			buf.append("ie.group_name not like '%TAU_CALLPATH%' ");
+			buf.append("and ie.group_name not like '%TAU_PHASE%')) ");
+			buf.append(" order by 1,2 ");
+			statement = db.prepareStatement(buf.toString());
+			statement.setInt(1, model.getTrial().getID());
+			statement.setInt(2, ((Metric)(model.getCurrentSelection())).getID());
 		}
 		return statement;
 	}
@@ -469,8 +636,9 @@ public class ChartData extends RMIChartData {
 			}
 			buf.append(" and m.name = ? ");
 			buf.append("and ims.inclusive_percentage < 100.0 ");
-			buf.append("and ims.exclusive_percentage < 1.0 ");
-			buf.append("and (ie.group_name is null or (");
+			buf.append("and ims.exclusive_percentage < ");
+			buf.append(model.getXPercent());
+			buf.append(" and (ie.group_name is null or (");
 			buf.append("ie.group_name not like '%TAU_CALLPATH%' ");
 			buf.append("and ie.group_name not like '%TAU_PHASE%')) group by (t.node_count * t.contexts_per_node * t.threads_per_context) order by 1");
 			
@@ -481,6 +649,26 @@ public class ChartData extends RMIChartData {
 			// The user wants to know the relative efficiency or speedup
 			// of all the events for one experiment, as the number of threads of 
 			// execution increases.
+			/*
+			buf.append("insert into (select distinct ");
+			buf.append("ie.name from interval_mean_summary ims ");
+			buf.append("inner join interval_event ie on ims.interval_event = ie.id ");
+			buf.append("inner join trial t on ie.trial = t.id ");
+			buf.append("inner join metric m on m.id = ims.metric ");
+			if (object instanceof RMIView) {
+				buf.append(model.getViewSelectionPath(true, true));
+			} else {
+				buf.append("where t.experiment = ");
+				buf.append(model.getExperiment().getID() + " ");
+			}
+			buf.append(" and m.name = ? ");
+			buf.append("and ims.exclusive_percentage > ");
+			buf.append(model.getXPercent());
+			buf.append(" and (ie.group_name is null or (");
+			buf.append("ie.group_name not like '%TAU_CALLPATH%' ");
+			buf.append("and ie.group_name not like '%TAU_PHASE%'));");
+			*/
+
 			buf.append("select ");
 			buf.append("(t.node_count * t.contexts_per_node * t.threads_per_context), ");
 
@@ -493,6 +681,7 @@ public class ChartData extends RMIChartData {
 			buf.append("inner join interval_event ie on ims.interval_event = ie.id ");
 			buf.append("inner join trial t on ie.trial = t.id ");
 			buf.append("inner join metric m on m.id = ims.metric ");
+			buf.append("left outer join working_table w on w.name = ie.name ");
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true));
 			} else {
@@ -501,11 +690,9 @@ public class ChartData extends RMIChartData {
 			}
 			
 			buf.append(" and m.name = ? ");
-//			buf.append("and ims.inclusive_percentage < 100.0 ");
-			buf.append("and ims.exclusive_percentage < 1.0 ");
-			buf.append("and (ie.group_name is null or (");
-			buf.append("ie.group_name not like '%TAU_CALLPATH%' ");
-			buf.append("and ie.group_name not like '%TAU_PHASE%')) group by (t.node_count * t.contexts_per_node * t.threads_per_context) order by 1");
+			buf.append("and w.name is null ");
+			buf.append("group by (t.node_count * t.contexts_per_node ");
+			buf.append("* t.threads_per_context) order by 1 ");
 
 			//System.out.println(buf.toString());
 			statement = db.prepareStatement(buf.toString());
