@@ -2,7 +2,6 @@ package server;
 
 import java.rmi.*;
 import java.rmi.server.*;
-import java.util.StringTokenizer;
 import java.util.List;
 import java.util.ArrayList;
 import java.util.Iterator;
@@ -11,14 +10,11 @@ import java.sql.SQLException;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.io.InputStream;
+
 import common.*;
-import edu.uoregon.tau.dms.dss.*;
-import edu.uoregon.tau.dms.database.*;
-import org.omegahat.R.Java.REvaluator;
-import org.omegahat.R.Java.ROmegahatInterpreter;
+import edu.uoregon.tau.perfdmf.*;
+import edu.uoregon.tau.perfdmf.database.*;
 import jargs.gnu.CmdLineParser;
-import java.net.URL;
-import java.net.MalformedURLException;
 
 /**
  * The main PerfExplorer Server class.  This class is defined as a singleton,
@@ -27,7 +23,7 @@ import java.net.MalformedURLException;
  * This server is accessed through RMI, and objects are passed back and forth
  * over the RMI link to the client.
  *
- * <P>CVS $Id: PerfExplorerServer.java,v 1.16 2005/08/12 00:23:01 khuck Exp $</P>
+ * <P>CVS $Id: PerfExplorerServer.java,v 1.24 2005/11/03 22:10:24 khuck Exp $</P>
  * @author  Kevin Huck
  * @version 0.1
  * @since   0.1
@@ -47,18 +43,13 @@ import java.net.MalformedURLException;
 public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfExplorer {
 	private static String USAGE = "Usage: PerfExplorerClient [{-h,--help}] {-c,--configfile}=<config_file> [{-e,--engine}=<analysis_engine>] [{-p,--port}=<port_number>]\n  where analysis_engine = R or Weka";
 
-	private String configFile = null;
 	private DatabaseAPI session = null;
 	private Semaphore dbControl = null;
-	private ROmegahatInterpreter rInterpreter = null;
-	private REvaluator rEvaluator = null;
 	private Queue requestQueue = null;
 	private java.lang.Thread timerThread = null;
 	private TimerThread timer = null;
 
 	private static PerfExplorerServer theServer = null;
-	private static int port = 9999;
-
 	/**
 	 * Static method to get the server instance reference.
 	 * Note: This method assumes the server has been instantiated.
@@ -102,8 +93,6 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		super(port);
 		PerfExplorerOutput.initialize(quiet);
 		theServer = this;
-		this.port = port;
-		this.configFile = configFile;
 		this.requestQueue = new Queue();
 		try {
 			this.session = new DatabaseAPI();
@@ -259,7 +248,7 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				statement.setInt(3, model.getTrial().getID());
 				statement.setString(4, RMIPerfExplorerModel.CORRELATION_ANALYSIS);
 			}
-			System.out.println(statement.toString());
+			//System.out.println(statement.toString());
 			ResultSet results = statement.executeQuery();
 			int analysisID = 0;
 			if (results.next() != false) {
@@ -506,51 +495,6 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		return session.db();
 	}
 
-	/**
-	 * The RInterpreter is a singleton object, so if the object has not yet
-	 * been instantiated, create one.  Then return the instance.
-	 * 
-	 * @return
-	 */
-	public ROmegahatInterpreter getRInterpreter () {
-		if (rInterpreter == null) {
-			String myArgs[] = new String[2];
-			myArgs[0] = new String("--silent");
-			myArgs[1] = new String("--vanilla");
-			rInterpreter = 
-				new ROmegahatInterpreter(ROmegahatInterpreter.fixArgs(myArgs), false);
-		}
-		return rInterpreter;
-	}
-
-	/**
-	 * The REvaluator is a singleton object, so if the object has not yet
-	 * been instantiated, create one.  Then return the instance.
-	 * 
-	 * @return
-	 */
-	public REvaluator getREvaluator () {
-		if (rEvaluator == null) {
-			rEvaluator = new REvaluator();
-		}
-		return rEvaluator;
-	}
-	
-	/**
-	 * End the R Session.  Currently only called on System.exit().
-	 */
-	public void endRSession() {
-		try {
-			rEvaluator.call("quit");
-		} catch (Exception e) { 
-			System.out.println(e);
-			e.printStackTrace();
-		}
-		rInterpreter = null;
-		rEvaluator = null;
-		System.out.println("R session over.");
-	}
-
 	/**
 	 * Check to see if the current request has been requested before.
 	 * 
@@ -720,8 +664,8 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		try {
 			DB db = this.getDB();
 			StringBuffer buf;
-			buf= new StringBuffer("select distinct m.name");
-			buf.append(" from metric m inner join trial t on m.trial = t.id");
+			buf= new StringBuffer("select distinct count(m.name), m.name ");
+			buf.append(" from metric m inner join trial t on m.trial = t.id ");
 			Object object = modelData.getCurrentSelection();
 			if (object instanceof RMIView) {
 				buf.append(modelData.getViewSelectionPath(true, true));
@@ -741,12 +685,19 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				}
 				buf.append(")");
 			}
+			buf.append(" group by m.name order by count(m.name) desc");
 			//System.out.println(buf.toString());
 			PreparedStatement statement = db.prepareStatement(buf.toString());
 			ResultSet results = statement.executeQuery();
+			// only get the metrics that are in all trials.
+			int trialCount = 0;
 			while (results.next() != false) {
-				metrics.add(results.getString(1));
+				if (trialCount == 0)
+					trialCount = results.getInt(1);
+				if (results.getInt(1) == trialCount)
+					metrics.add(results.getString(2));
 			}
+			results.close();
 			statement.close();
 		} catch (Exception e) {
 			String error = "ERROR: Couldn't select the metrics from the database!";
@@ -795,7 +746,7 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				buf.append(")");
 			}
 			PreparedStatement statement = db.prepareStatement(buf.toString());
-			System.out.println(statement.toString());
+			//System.out.println(statement.toString());
 			ResultSet results = statement.executeQuery();
 			while (results.next() != false) {
 				events.add(results.getString(1));
@@ -1284,6 +1235,9 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 			System.exit(-1);
 		}
 
+		if (quiet == null) 
+			quiet = new Boolean(false);
+
 		if (configFile == null) {
 			System.err.println("Please enter a valid config file.");
 			System.err.println(USAGE);
