@@ -74,13 +74,13 @@ cat <<EOF > /tmp/makefile.tau$$
 EOF
 else
 cat <<EOF > /tmp/makefile.tau$$
-  include $MAKEFILE
-  all:
+include $MAKEFILE
+all:
 	@\$(TAU_COMPILER) $TAUCOMPILER_OPTIONS \$(TAU_CC) $* 
 
 EOF
 fi
 
-make -f /tmp/makefile.tau$$
+make -s -f /tmp/makefile.tau$$
 /bin/rm -f /tmp/makefile.tau$$
 
