@@ -347,6 +347,7 @@ for arg in "$@"
 		*.cc|*.CC|*.cpp|*.CPP|*.cxx|*.CXX|*.C)
 			fileName=$arg
 			arrFileName[$numFiles]=$arg
+			arrFileNameDirectory[$numFiles]=`dirname $arg`
 			numFiles=numFiles+1
 			pdtParserType=cxxparse
 			groupType=$group_C
@@ -355,6 +356,7 @@ for arg in "$@"
 		*.c)
 			fileName=$arg
 			arrFileName[$numFiles]=$arg
+			arrFileNameDirectory[$numFiles]=`dirname $arg`
 			numFiles=numFiles+1
 			pdtParserType=cparse
 			groupType=$group_c
@@ -363,6 +365,7 @@ for arg in "$@"
 		*.f|*.F|*.f90|*.F90|*.f77|*.F77|*.f95|*.F95)
 			fileName=$arg
 			arrFileName[$numFiles]=$arg
+			arrFileNameDirectory[$numFiles]=`dirname $arg`
 			numFiles=numFiles+1
 			if [ $fortranParserDefined == $FALSE ]; then
 				#If it is not passed EXPLICITY, use the default f95parse.
@@ -483,6 +486,10 @@ while [ $tempCounter -lt $numFiles ]; do
 	  base=${base}.pomp
 	  cmdToExecute="${optOpariTool} $optOpariOpts ${arrFileName[$tempCounter]} $base$suf"
 	  evalWithDebugMessage "$cmdToExecute" "Parsing with Opari" 
+          if [ ! -f $base$suf ]; then
+            echoIfVerbose "ERROR: Did not generate .pomp file"
+	    printError "$optOpariTool" "$cmdToExecute"
+          fi
 	  arrFileName[$tempCounter]=$base$suf
 	fi
 	newFile=${base}.inst${suf}
@@ -517,7 +524,7 @@ if [ $numFiles == 0 ]; then
 
 	if [ $hasMpi == $FALSE ]; then
 		echoIfDebug "Before filtering -l*mpi* options command is: $regularCmd"
-		regularCmd=`echo $regularCmd | sed -e 's/-l[a-zA-Z0-9]*mpi[a-zA-Z0-9+_]*//g'`
+		regularCmd=`echo $regularCmd | sed -e 's/-l[a-zA-Z0-9]*mpi[a-zA-Z.0-9+_]*//g'`
 		echoIfDebug "After filtering -l*mpi* options command is: $regularCmd"
 	fi
 
@@ -685,7 +692,8 @@ if [ $gotoNextStep == $TRUE ]; then
 
 			tempTauFileName=${arrTau[$tempCounter]##*/}
 			instrumentedFileForCompilation="$tempTauFileName"
-			newCmd="$CMD  $argsRemaining $instrumentedFileForCompilation  $OUTPUTARGSFORTAU $optCompile"
+#			newCmd="$CMD  $argsRemaining $instrumentedFileForCompilation  $OUTPUTARGSFORTAU $optCompile"
+			newCmd="$CMD -I ${arrFileNameDirectory[$tempCounter]} $argsRemaining $instrumentedFileForCompilation  $OUTPUTARGSFORTAU $optCompile"
 
 			#echoIfDebug "cmd before appending the .o file is $newCmd"
 			if [ $hasAnOutputFile == $TRUE ]; then
@@ -730,7 +738,8 @@ if [ $gotoNextStep == $TRUE ]; then
 			tempTauFileName=${arrTau[$tempCounter]##*/}
 			instrumentedFileForCompilation=" $tempTauFileName"
 
-			newCmd="$CMD $argsRemaining  -c $instrumentedFileForCompilation  $OUTPUTARGSFORTAU $optCompile -o $outputFile"
+#			newCmd="$CMD $argsRemaining  -c $instrumentedFileForCompilation  $OUTPUTARGSFORTAU $optCompile -o $outputFile"
+			newCmd="$CMD $argsRemaining  -I ${arrFileNameDirectory[$tempCounter]} -c $instrumentedFileForCompilation  $OUTPUTARGSFORTAU $optCompile -o $outputFile"
 
 			evalWithDebugMessage "$newCmd" "Compiling (Individually) with Instrumented Code"
 			if [  ! -e $outputFile ]; then
