@@ -34,6 +34,12 @@ bool multiThreaded = false;
 /* implementation of callback routines */
 map< pair<int,int>, int, less< pair<int,int> > > EOF_Trace;
 map< int,int, less<int > > numthreads; 
+//map< int,int > nodename;
+map <int, int> nodenum;
+
+map<pair<int,int>,int, less< pair<int,int> > > GlobalId;
+
+int countnodes = 0;
 /* numthreads[k] is no. of threads in rank k */
 
 int EndOfTrace = 0;  /* false */
@@ -57,29 +63,31 @@ struct {
 int sampgroupid = 0;
 int sampclassid = 0; 
 vector<stack <unsigned int> > callstack;
-int *offset = 0; 
+//int *offset = 0; 
 
 
 /* FIX GlobalID so it takes into account numthreads */
 /* utilities */
+/*
 int GlobalId(int localnodeid, int localthreadid)
 {
+  localnodeid=nodename[localnodeid];
   if (multiThreaded)
   {
     if (offset == (int *) NULL)
     {
       printf("Error: offset vector is NULL in GlobalId()\n");
       return localnodeid;
-    }
+    }*/
     
     /* for multithreaded programs, modify this routine */
-    return offset[localnodeid]+localthreadid;  /* for single node program */
-  }
+ //   return offset[localnodeid]+localthreadid;  /* for single node program */
+/*  }
   else
   { 
     return localnodeid;
   }
-}
+}*/
 
 /* implementation of callback routines */
 /***************************************************************************
@@ -92,7 +100,7 @@ int EnterState(void *userData, double time,
 {
   dprintf("Entered state %d time %g nid %d tid %d\n", 
 		  stateid, time, nodeid, tid);
-  int cpuid = GlobalId(nodeid, tid);
+  int cpuid = GlobalId[pair<int,int>(nodeid, tid)];
 
   if (cpuid >= callstack.size()) 
   {
@@ -107,18 +115,23 @@ int EnterState(void *userData, double time,
 }
 
 /***************************************************************************
- * Description: EnterState is called at routine exit by trace input library
+ * Description: LeaveState is called at routine exit by trace input library
  * 		This is a callback routine which must be registered by the 
  * 		trace converter. 
  ***************************************************************************/
-int LeaveState(void *userData, double time, unsigned int nid, unsigned int tid)
+int LeaveState(void *userData, double time, unsigned int nid, unsigned int tid, unsigned int stateid)
 {
   dprintf("Leaving state time %g nid %d tid %d\n", time, nid, tid);
-  int cpuid = GlobalId(nid, tid);
-  int stateid = callstack[cpuid].top();
+  int cpuid = GlobalId[pair<int,int>(nid, tid)];
+  if (callstack[cpuid].size()==0) 
+  {
+    fprintf(stderr, "ERROR: tau2vtf: LeaveState() cpuid %d has state departure before entry\n", cpuid);
+    exit(1);
+  }
+  int localstateid = callstack[cpuid].top();
   callstack[cpuid].pop();
   
-  VTF3_WriteUpfrom(userData, time, stateid, cpuid, VTF3_SCLNONE);
+  VTF3_WriteUpfrom(userData, time, localstateid, cpuid, VTF3_SCLNONE);
   return 0;
 }
 
@@ -145,8 +158,20 @@ const char *threadName )
 {
   dprintf("DefThread nid %d tid %d, thread name %s\n", 
 		  nodeToken, threadToken, threadName);
+		  
+  
+		  
   EOF_Trace[pair<int,int> (nodeToken,threadToken) ] = 0; /* initialize it */
-  numthreads[nodeToken] = numthreads[nodeToken] + 1; 
+  
+  
+  numthreads[nodeToken] = numthreads[nodeToken] + 1;
+  /*if(numthreads[nodeToken]==1)
+  {
+	nodename[nodeToken]=countnodes;//nodename.size();
+	nodenum[countnodes]=nodeToken;
+	countnodes++;
+	printf("Node: %d, ID: %d\n",nodeToken,nodename[nodeToken]);
+  }*/
   if (threadToken > 0) multiThreaded = true; 
   return 0;
 }
@@ -278,7 +303,7 @@ int EventTrigger( void *userData, double time,
   dprintf("EventTrigger: time %g, nid %d tid %d event id %d triggered value %lld \n", time, nodeToken, threadToken, userEventToken, userEventValue);
 
   int type = VTF3_VALUETYPE_UINT;
-  int cpuid = GlobalId (nodeToken, threadToken); /* GID */
+  int cpuid = GlobalId[pair<int,int>(nodeToken, threadToken)]; /* GID */
   int samplearraydim = 1; 
 
   /* write the sample data */
@@ -299,7 +324,8 @@ int SendMessage( void *userData, double time,
 		unsigned int destinationNodeToken,
 		unsigned int destinationThreadToken,
 		unsigned int messageSize,
-		unsigned int messageTag )
+		unsigned int messageTag,
+		unsigned int messageComm)
 {
   dprintf("SendMessage: time %g, source nid %d tid %d, destination nid %d tid %d, size %d, tag %d\n", 
 		  time, 
@@ -307,8 +333,8 @@ int SendMessage( void *userData, double time,
 		  destinationNodeToken, destinationThreadToken,
 		  messageSize, messageTag);
 
-  int source = GlobalId(sourceNodeToken, sourceThreadToken);
-  int dest   = GlobalId(destinationNodeToken, destinationThreadToken);
+  int source = GlobalId[pair<int,int>(sourceNodeToken, sourceThreadToken)];
+  int dest   = GlobalId[pair<int,int>(destinationNodeToken, destinationThreadToken)];
   VTF3_WriteSendmsg(userData, time, source, dest, TAU_DEFAULT_COMMUNICATOR, 
 	messageTag, messageSize, VTF3_SCLNONE);
   return 0;
@@ -325,7 +351,8 @@ int RecvMessage( void *userData, double time,
 		unsigned int destinationNodeToken,
 		unsigned int destinationThreadToken,
 		unsigned int messageSize,
-		unsigned int messageTag )
+		unsigned int messageTag,
+		unsigned int messageComm)
 {
   dprintf("RecvMessage: time %g, source nid %d tid %d, destination nid %d tid %d, size %d, tag %d\n", 
 		  time, 
@@ -333,8 +360,8 @@ int RecvMessage( void *userData, double time,
 		  destinationNodeToken, destinationThreadToken,
 		  messageSize, messageTag);
 
-  int source = GlobalId(sourceNodeToken, sourceThreadToken);
-  int dest   = GlobalId(destinationNodeToken, destinationThreadToken);
+  int source = GlobalId[pair<int,int>(sourceNodeToken, sourceThreadToken)];
+  int dest   = GlobalId[pair<int,int>(destinationNodeToken, destinationThreadToken)];
 
   VTF3_WriteRecvmsg(userData, time, dest, source, TAU_DEFAULT_COMMUNICATOR, 
 	messageTag, messageSize, VTF3_SCLNONE);
@@ -463,7 +490,7 @@ int main(int argc, char **argv)
   firstpass.DefThread = DefThread;
   firstpass.EndTrace = EndTrace;
   firstpass.DefClkPeriod = ClockPeriod;
-  firstpass.DefThread = DefThread;
+  //firstpass.DefThread = DefThread;
   firstpass.DefStateGroup = DefStateGroup;
   firstpass.DefState = DefState;
   firstpass.SendMessage = 0; /* Important to declare these as null! */
@@ -483,13 +510,28 @@ int main(int argc, char **argv)
 #endif 
   }
   while ((recs_read >=0) && (!EndOfTrace));
-  /* reset the position of the trace to the first record */
+  
+  /* reset the position of the trace to the first record 
+     Initialize global id map*/
+  int global = 0;
   for (map< pair<int,int>, int, less< pair<int,int> > >:: iterator it = 
 		  EOF_Trace.begin(); it != EOF_Trace.end(); it++)
   { /* Explicilty mark end of trace to be not over */ 
+     GlobalId[pair<int,int>((*it).first)]=global;
+     nodenum[global]=((*it).first).first;
+     //printf("nodenum: %d, nodeid: %d, threadid: %d\n",global, ((*it).first).first,((*it).first).second);
+     global++;
     (*it).second = 0;
   }
 
+  /*
+  for (map< pair<int,int>, int, less< pair<int,int> > >:: iterator it = 
+		  GlobalId.begin(); it != GlobalId.end(); it++)
+  { // Explicilty mark end of trace to be not over 
+    GlobalId[*it] = global;
+    global++;
+  }*/
+  
   int totalnidtids = EOF_Trace.size(); 
   /* This is ok for single threaded programs. For multi-threaded programs
    * we'll need to modify the way we describe the cpus/threads */
@@ -497,31 +539,35 @@ int main(int argc, char **argv)
 
   /* Then write out the thread names if it is multi-threaded */
   if (multiThreaded)
-  { /* create the thread ids */
+  {
+    /* create the thread ids */
     unsigned int groupid = 0x1 << 31; /* Valid vampir group id nos */
     int tid = 0; 
     int nodes = numthreads.size(); /* total no. of nodes */ 
     int *threadnumarray = new int[nodes]; 
-    offset = new int[nodes+1];
-    offset[0] = 0; /* no offset for node 0 */
+    //offset = new int[nodes+1];
+    //offset[0] = 0; /* no offset for node 0 */
+    
     for (i=0; i < nodes; i++)
-    { /* one for each node */
+    {
+      // one for each node 
       threadnumarray[i] = numthreads[i]; 
-      offset[i+1] = offset[i] + numthreads[i]; 
+      //offset[i+1] = offset[i] + numthreads[i]; 
     }
     unsigned int *cpuidarray = new unsigned int[totalnidtids]; /* max */
     /* next, we write the cpu name and a group name for node/threads */
+    
     for (i=0; i < nodes; i++)
-    { 
-      char name[32];
+    {
+      char name[64];
       for (tid = 0; tid < threadnumarray[i]; tid++)
       {
-        sprintf(name, "node %d, thread %d", i, tid);
-        int cpuid = GlobalId(i,tid);
+        sprintf(name, "node %d, thread %d", nodenum[i], tid);
+        int cpuid = GlobalId[pair<int,int>(nodenum[i],tid)];
         cpuidarray[tid] = cpuid;
         VTF3_WriteDefcpuname(fcb, cpuid, name);
       }
-      sprintf(name, "Node %d", i);
+      sprintf(name, "Node %d", nodenum[i]);
       groupid ++; /* let flat group for samples take the first one */
       /* Define a group: threadnumarray[i] represents no. of threads in node */
       VTF3_WriteDefcpugrp(fcb, groupid, threadnumarray[i], 
@@ -529,6 +575,18 @@ int main(int argc, char **argv)
     }
     delete[] cpuidarray;
   }
+  else
+  {
+     int nodes = numthreads.size();
+     for(i=0;i<nodes;i++)
+     {
+         char name[64];
+	 sprintf(name, "node %d",nodenum[i]);
+	 int cpuid = GlobalId[pair<int,int>(nodenum[i],0)];
+	 //printf("id: %d, name: %d\n",cpuid, nodenum[i]);
+	 VTF3_WriteDefcpuname(fcb, cpuid, name);
+     }
+  }
 
 
   unsigned int *idarray = new unsigned int[totalnidtids];
@@ -615,9 +673,9 @@ int main(int argc, char **argv)
 
 
 /***************************************************************************
- * $RCSfile: tau2vtf.cpp,v $   $Author: sameer $
- * $Revision: 1.8 $   $Date: 2005/01/05 22:46:38 $
- * VERSION_ID: $Id: tau2vtf.cpp,v 1.8 2005/01/05 22:46:38 sameer Exp $
+ * $RCSfile: tau2vtf.cpp,v $   $Author: wspear $
+ * $Revision: 1.15 $   $Date: 2005/11/11 20:08:02 $
+ * VERSION_ID: $Id: tau2vtf.cpp,v 1.15 2005/11/11 20:08:02 wspear Exp $
  ***************************************************************************/
 
 
